@@ -13,7 +13,7 @@
 #ifndef _ABOUT_DLG_H_INCLUDED_
 #define _ABOUT_DLG_H_INCLUDED_
 
-// wxwindows
+// wxWidgets
 #include "wx/dialog.h"
 
 /**
@@ -27,8 +27,9 @@ public:
    * constructor
    *
    * @param parent parent window
+   * @param locale locale used by the application
    */
-  AboutDlg (wxWindow * parent);
+  AboutDlg (wxWindow * parent, const wxLocale & locale);
 
   /**
    * destructor
