@@ -13,6 +13,10 @@
 #ifndef _RAPIDSVN_CONFIG_HPP_INCLUDED_
 #define _RAPIDSVN_CONFIG_HPP_INCLUDED_
 
+// wxWidgets
+#include "wx/wx.h"
+
+
 /**
  * Do we want to use the simple single threaded or multi-threaded
  * action worker?
@@ -23,6 +27,29 @@
 #define USE_THREADED_WORKER
 #endif
 
+/**
+ * Do we want startup tips?
+ */
+//#define USE_STARTUP_TIPS
+
+/**
+ * Do we want support for online help?
+ */
+//#define USE_HTML_HELP
+
+// consitency checking with wx settings
+#ifdef USE_HTML_HELP
+#ifndef wxUSE_WXHTML_HELP
+#undef USE_HTML_HELP
+#endif
+#endif
+
+#ifdef USE_STARTUP_TIPS
+#ifndef wxUSE_STARTUP_TIPS
+#undef USE_STARTUP_TIPS
+#endif
+#endif
+
 #endif
 /* -----------------------------------------------------------------
  * local variables:
