@@ -13,7 +13,7 @@
 #ifndef _EXCEPTIONS_H_INCLUDED_
 #define _EXCEPTIONS_H_INCLUDED_
 
-// wxwindows
+// wxWidgets
 #include "wx/string.h"
 
 class RapidSvnEx
@@ -23,7 +23,7 @@ public:
   long code;
 
 public:
-   RapidSvnEx (const wxString & __estr = "", const long __code = -1);
+   RapidSvnEx (const wxString & __estr = wxEmptyString, const long __code = -1);
 
    virtual ~ RapidSvnEx ();
 
