@@ -17,7 +17,7 @@
 // stl
 #include <exception>
 
-// wxwindows
+// wxWidgets
 #include "wx/wx.h"
 #include "wx/confbase.h"
 #include "wx/filename.h"
@@ -60,7 +60,7 @@
 
 
 /**
- * The index from where there will be only images not related 
+ * The index from where there will be only images not related
  * to the status.
  */
 static const int START_EXTRA_IMGS=15;
@@ -90,12 +90,13 @@ static int IMAGE_INDEX[IMG_INDX_COUNT];
  * Tags for wxConfig file settings, defined here to avoid duplicate
  * hard coded strings.
  */
-static const char ConfigSortColumn[]       = "/FileListCtrl/SortColumn";
-static const char ConfigSortOrder[]        = "/FileListCtrl/SortOrder";
-static const char ConfigColumnWidthFmt[]   = "/FileListCtrl/Column%sWidth";
-static const char ConfigColumnVisibleFmt[] = "/FileListCtrl/Column%sVisible";
-static const char ConfigWithUpdate[]       = "/FileListCtrl/WithUpdate";
-static const char ConfigFlatView[]         = "/FileListCtrl/FlatView";
+static const wxChar ConfigSortColumn[]       = wxT("/FileListCtrl/SortColumn");
+static const wxChar ConfigSortOrder[]        = wxT("/FileListCtrl/SortOrder");
+static const wxChar ConfigColumnWidthFmt[]   = wxT("/FileListCtrl/Column%sWidth");
+static const wxChar ConfigColumnVisibleFmt[] = wxT("/FileListCtrl/Column%sVisible");
+static const wxChar ConfigWithUpdate[]       = wxT("/FileListCtrl/WithUpdate");
+static const wxChar ConfigFlatView[]         = wxT("/FileListCtrl/FlatView");
+static const wxChar ConfigShowUnversioned[]  = wxT("/FileListCtrl/ShowUnversioned");
 
 /**
  * test if the given status entry is a file or
@@ -106,13 +107,13 @@ static const char ConfigFlatView[]         = "/FileListCtrl/FlatView";
  *       possible
  *
  * @param status status entry
- * @retval false is invalid status 
+ * @retval false is invalid status
  */
-static bool 
+static bool
 IsDir (const svn::Status * status)
 {
   // invalid entry
-  
+
   if (!status)
   {
     return false;
@@ -130,9 +131,9 @@ IsDir (const svn::Status * status)
   {
     return entry->kind == svn_node_dir;
   }
-  
+
   // unversioned.
-  return wxDirExists (status->path ());
+  return wxDirExists (Utf8ToLocal (status->path ()));
 }
 
 static const int
@@ -189,13 +190,13 @@ Compare (svn_wc_status_kind status1, svn_wc_status_kind status2, bool newer1, bo
   {
     status2 = FAKE_SVN_WC_OUT_OF_DATE;
   }
-  
+
   if (status1 == status2)
   {
     return 0;
   }
-  
-  static svn_wc_status_kind lookup[] = 
+
+  static svn_wc_status_kind lookup[] =
   {
     svn_wc_status_external,
     svn_wc_status_ignored,
@@ -214,7 +215,7 @@ Compare (svn_wc_status_kind status1, svn_wc_status_kind status2, bool newer1, bo
     svn_wc_status_none,
     (svn_wc_status_kind)0
   };
-  
+
   for (svn_wc_status_kind* pkind = lookup; *pkind; ++pkind)
   {
     if (*pkind == status1)
@@ -226,7 +227,7 @@ Compare (svn_wc_status_kind status1, svn_wc_status_kind status2, bool newer1, bo
       return 1;
     }
   }
-  
+
   // Unrecognised either
   return 0;
 }
@@ -241,8 +242,11 @@ Compare (svn_wc_status_kind status1, svn_wc_status_kind status2, bool newer1, bo
 static int
 ComparePaths (const char * p1, const char * p2)
 {
-  wxFileName fn1 (p1);
-  wxFileName fn2 (p2);
+  wxString wxp1 (Utf8ToLocal (p1));
+  wxString wxp2 (Utf8ToLocal (p2));
+
+  wxFileName fn1 (wxp1);
+  wxFileName fn2 (wxp2);
 
   wxString path1 = fn1.GetPath ();
   wxString path2 = fn2.GetPath ();
@@ -250,13 +254,13 @@ ComparePaths (const char * p1, const char * p2)
   int res = 0;
 
   // Is p2 a subdir or entry of p1?
-  if (path1.CmpNoCase (p2) == 0)
+  if (path1.CmpNoCase (wxp2) == 0)
   {
     return -1;
   }
 
   // Is p1 a subdir or entry of p2?
-  if (path2.CmpNoCase (p1) == 0)
+  if (path2.CmpNoCase (wxp1) == 0)
   {
     return 1;
   }
@@ -307,8 +311,11 @@ Compare (const char * s1, const char * s2)
 {
   const char * sv1 = s1 == 0 ? "" : s1;
   const char * sv2 = s2 == 0 ? "" : s2;
-  
-  return wxString (sv1).CmpNoCase (sv2);
+
+  wxString wx1 (Utf8ToLocal (sv1));
+  wxString wx2 (Utf8ToLocal (sv2));
+
+  return wx1.CmpNoCase (wx2);
 }
 
 /**
@@ -319,7 +326,7 @@ Compare (const char * s1, const char * s2)
  * @param column to compare
  * @return -1
  */
-static int 
+static int
 CompareColumn (svn::Status * ps1,
                svn::Status * ps2,
                int column)
@@ -328,28 +335,28 @@ CompareColumn (svn::Status * ps1,
   svn::Entry e1 (ps1->entry ());
   svn::Entry e2 (ps2->entry ());
 
-  bool newer1 = 
+  bool newer1 =
     (ps1->reposTextStatus () == svn_wc_status_modified) ||
     (ps1->reposPropStatus () == svn_wc_status_modified);
-  bool newer2 = 
+  bool newer2 =
     (ps2->reposTextStatus () == svn_wc_status_modified) ||
     (ps2->reposPropStatus () == svn_wc_status_modified);
-  
+
   switch (column)
   {
-  case FileListCtrl::COL_NAME:                     
+  case FileListCtrl::COL_NAME:
     res = Compare (ps1->path (), ps2->path ());
     break;
 
-  case FileListCtrl::COL_PATH: 
+  case FileListCtrl::COL_PATH:
     res = ComparePaths (ps1->path (), ps2->path ());
     break;
 
-  case FileListCtrl::COL_REV:     
+  case FileListCtrl::COL_REV:
     res = Compare (e1.revision (), e2.revision ());
     break;
 
-  case FileListCtrl::COL_CMT_REV:     
+  case FileListCtrl::COL_CMT_REV:
     res = Compare (e1.cmtRev (), e2.cmtRev ());
     break;
 
@@ -365,6 +372,10 @@ CompareColumn (svn::Status * ps1,
     res = Compare (ps1->propStatus (), ps2->propStatus (), newer1, newer2);
     break;
 
+  case FileListCtrl::COL_EXTENSION:
+    res = wxFileName(Utf8ToLocal (ps1->path())).GetExt().CmpNoCase (wxFileName(Utf8ToLocal (ps2->path())).GetExt());
+    break;
+
   case FileListCtrl::COL_CMT_DATE:
     res = Compare (e1.cmtDate (), e2.cmtDate ());
     break;
@@ -421,7 +432,7 @@ CompareColumn (svn::Status * ps1,
 }
 
 /**
- * check the given @a svn::Status entries and the 
+ * check the given @a svn::Status entries and the
  * sort settings. Not only the @a SortColumn is
  * used for comparison but secondary columns as
  * well so the entries are always sorted in
@@ -452,7 +463,7 @@ CompareItems (svn::Status * ps1, svn::Status * ps2,
 
   switch (SortColumn)
   {
-  case FileListCtrl::COL_NAME:                     
+  case FileListCtrl::COL_NAME:
     res = CompareColumn (ps1, ps2, FileListCtrl::COL_NAME);
     if (res == 0)
     {
@@ -493,7 +504,7 @@ CompareItems (svn::Status * ps1, svn::Status * ps2,
 /**
  * array with column captions
  */
-static const char * 
+static const wxChar *
 COLUMN_CAPTIONS[FileListCtrl::COL_COUNT] =
 {
   _("Name"),
@@ -504,6 +515,7 @@ COLUMN_CAPTIONS[FileListCtrl::COL_COUNT] =
   _("Status"),
   _("Prop Status"),
   _("Last Changed"),
+  _("Extension"),
   _("Date"),
   _("Prop Date"),
   _("Checksum"),
@@ -521,32 +533,33 @@ COLUMN_CAPTIONS[FileListCtrl::COL_COUNT] =
  * array with column names. These names are
  * used to save and retrieve column specific
  * preferences.
- * 
+ *
  * Note: these string must not be translatable
  *       so dont enclose them in _( )
  */
-static const char *
+static const wxChar *
 COLUMN_NAMES[FileListCtrl::COL_COUNT] =
 {
-  "Name",
-  "Path",
-  "Revision",
-  "RepRev",
-  "Author",
-  "Status",
-  "PropStatus",
-  "LastChanged",
-  "Date",
-  "PropDate",
-  "Checksum",
-  "Url",
-  "Repository",
-  "UUID",
-  "Schedule",
-  "Copied",
-  "ConflictOld",
-  "ConflictNew",
-  "ConflictWork"
+  wxT("Name"),
+  wxT("Path"),
+  wxT("Revision"),
+  wxT("RepRev"),
+  wxT("Author"),
+  wxT("Status"),
+  wxT("PropStatus"),
+  wxT("LastChanged"),
+  wxT("Extension"),
+  wxT("Date"),
+  wxT("PropDate"),
+  wxT("Checksum"),
+  wxT("Url"),
+  wxT("Repository"),
+  wxT("UUID"),
+  wxT("Schedule"),
+  wxT("Copied"),
+  wxT("ConflictOld"),
+  wxT("ConflictNew"),
+  wxT("ConflictWork")
 };
 
 
@@ -565,6 +578,7 @@ public:
   svn::Context * Context;
   wxString Path;
   bool WithUpdate;
+  bool ShowUnversioned;
   wxImageList *ImageListSmall;
   bool ColumnVisible[COL_COUNT];
   wxString ColumnCaption[COL_COUNT];
@@ -573,9 +587,9 @@ public:
 
   /** default constructor */
   Data ()
-    : SortIncreasing (true), SortColumn (COL_NAME), 
+    : SortIncreasing (true), SortColumn (COL_NAME),
       DirtyColumns (true), FlatMode (false), Context (0),
-      Path (""), WithUpdate (false)
+      WithUpdate (false)
   {
     ImageListSmall = new wxImageList (16, 16, TRUE);
 
@@ -609,12 +623,12 @@ public:
     delete ImageListSmall;
   }
 
-  /** 
+  /**
    * get the real column. @a clickedColumn is only the index
    * of the visible column that got clicked. If there are
    * invisible columns this translates to something completely different
    */
-  int 
+  int
   GetRealColumn (int clickedColumn)
   {
     int colIndex;
@@ -641,8 +655,8 @@ public:
     svn::Status * ps2 = (svn::Status *) item2;
     Data *data = (Data *) (sortData);
 
-    if (ps1 && ps2) 
-      return CompareItems (ps1, ps2, data->SortColumn, 
+    if (ps1 && ps2)
+      return CompareItems (ps1, ps2, data->SortColumn,
                            data->SortIncreasing);
     else
       return 0;
@@ -657,9 +671,10 @@ public:
   {
       // Get settings from config file:
     wxConfigBase *config = wxConfigBase::Get ();
-    config->Read (ConfigWithUpdate, &WithUpdate);
-    config->Read (ConfigFlatView,   &FlatMode);
-    
+    config->Read (ConfigWithUpdate,      &WithUpdate);
+    config->Read (ConfigFlatView,        &FlatMode);
+    config->Read (ConfigShowUnversioned, &ShowUnversioned, (bool) true);
+
     SortColumn = config->Read (ConfigSortColumn, (long) 0);
     SortIncreasing = config->Read (ConfigSortOrder, (long) 1) ? true : false;
 
@@ -669,7 +684,7 @@ public:
       wxString key;
       key.Printf (ConfigColumnVisibleFmt, COLUMN_NAMES[col]);
       ColumnVisible[col] = config->Read (key, (long) 1) != 0;
-  
+
       key.Printf (ConfigColumnWidthFmt, COLUMN_NAMES[col]);
       long width = (long)GetDefaultWidth (col);
       ColumnWidth[col] = config->Read (key, width);
@@ -685,9 +700,10 @@ public:
   {
     // Write settings to config file:
     wxConfigBase *config = wxConfigBase::Get ();
-    config->Write (ConfigWithUpdate, WithUpdate);
-    config->Write (ConfigFlatView,   FlatMode);
-    
+    config->Write (ConfigWithUpdate,      WithUpdate);
+    config->Write (ConfigFlatView,        FlatMode);
+    config->Write (ConfigShowUnversioned, ShowUnversioned);
+
     config->Write (ConfigSortColumn, (long) SortColumn);
     config->Write (ConfigSortOrder, (long) (SortIncreasing ? 1 : 0));
     // loop through all the columns
@@ -701,7 +717,7 @@ public:
       config->Write (key, (long) ColumnVisible[col]);
     }
   }
-};  
+};
 
 
 /**
@@ -714,7 +730,7 @@ GetImageIndex (int textIndex, int propIndex)
   int image = 0;
   if ((textIndex >= 0) && (textIndex <= IMG_INDX_COUNT))
   {
-    if ( (textIndex == svn_wc_status_normal) && 
+    if ( (textIndex == svn_wc_status_normal) &&
          (propIndex > svn_wc_status_normal) )
     {
       if ( (propIndex >= 0) && (propIndex <= IMG_INDX_COUNT) )
@@ -741,7 +757,7 @@ BEGIN_EVENT_TABLE (FileListCtrl, wxListCtrl)
   EVT_CONTEXT_MENU (FileListCtrl::OnContextMenu)
 END_EVENT_TABLE ()
 
-FileListCtrl::FileListCtrl (wxWindow * parent, const wxWindowID id, 
+FileListCtrl::FileListCtrl (wxWindow * parent, const wxWindowID id,
                             const wxPoint & pos, const wxSize & size)
   : wxListView (parent, id, pos, size, wxLC_REPORT)
 {
@@ -797,24 +813,24 @@ FileListCtrl::UpdateFileList (const wxString & path)
 void
 FileListCtrl::UpdateFileList ()
 {
-  const wxString & path = m->Path;
+  std::string pathUtf8;
+  LocalToUtf8 (m->Path, pathUtf8);
+  const bool isNative (!svn::Url::isValid (pathUtf8.c_str ()));
   // delete all the items in the list to display the new ones
   DeleteAllItems ();
 
   UpdateColumns ();
 
-  wxLogStatus (_("Listing entries in '%s'"), path.c_str ());
+  wxLogStatus (_("Listing entries in '%s'"), m->Path.c_str ());
 
   // Hide the list to speed up inserting
   Hide ();
 
-  std::string stdpath (path.c_str ());
-
   svn::Client client (m->Context);
   const svn::StatusEntries statusVector =
-    client.status (path.c_str (), m->FlatMode, true, m->WithUpdate);
+    client.status (pathUtf8.c_str (), m->FlatMode, true, m->WithUpdate);
   svn::StatusEntries::const_iterator it;
-  const size_t pathLength = path.Length () + 1;
+  const size_t pathUtf8Length = pathUtf8.length () + 1;
 
   for (it = statusVector.begin (); it != statusVector.end (); it++)
   {
@@ -824,26 +840,37 @@ FileListCtrl::UpdateFileList ()
     int i = GetItemCount ();
 
     // truncate the first part of the path
-    wxString fullPath (status.path ());
-    wxString filename (fullPath.Mid (pathLength));
-    if (filename.Length () == 0)
+    std::string fullPath (status.path ());
+    std::string filename;
+//    wxString fullPath (status.path ());
+//    wxString filename (fullPath.Mid (pathLength));
+    if (fullPath.length () <= pathUtf8Length)
     {
-      values[COL_NAME] = ".";
+      values[COL_NAME] = wxT(".");
     }
     else
     {
-      values[COL_NAME] = wxFileNameFromPath (filename);
-    }
-    if (m->ColumnVisible[COL_PATH])
-    {
-      wxFileName path (fullPath);
-      values[COL_PATH] = path.GetFullPath ();
+      filename = fullPath.substr (pathUtf8Length);
+      wxString wxstr = Utf8ToLocal (filename);
+      values[COL_NAME] = wxFileNameFromPath (wxstr);
     }
 
-    wxString text;
+    wxString wxFullPath = Utf8ToLocal (status.path ());
+    if (m->ColumnVisible[COL_PATH] || m->ColumnVisible[COL_EXTENSION])
+    {
+      svn::Path path (fullPath.c_str ());
+      std::string dir, filename, ext;
+      path.split (dir, filename, ext);
+
+      if (isNative)
+        values[COL_PATH]    = Utf8ToLocal (path.native ().c_str ());
+      else
+        values[COL_PATH]    = wxFullPath;
+      values[COL_EXTENSION] = Utf8ToLocal (ext.c_str ());
+    }
 
     int imageIndex = 0;
-    bool newer = 
+    bool newer =
       (status.reposTextStatus () == svn_wc_status_modified) ||
       (status.reposPropStatus () == svn_wc_status_modified);
 
@@ -855,7 +882,7 @@ FileListCtrl::UpdateFileList ()
             (status.propStatus () == svn_wc_status_modified))
           imageIndex = GetImageIndex (
             IMG_INDX_MODIFIED_VERSIONED_FOLDER, -1);
-        else 
+        else
           imageIndex = GetImageIndex (
             IMG_INDX_VERSIONED_FOLDER, -1);
 
@@ -881,11 +908,11 @@ FileListCtrl::UpdateFileList ()
     {
       // unversioned entries dont carry dir info
       // with them. must find this out by ourself
-      if (wxDirExists (status.path ()))
+      if (wxDirExists (wxFullPath))
       {
         imageIndex = GetImageIndex (IMG_INDX_FOLDER, -1);
       }
-      else if (wxFileExists (status.path ()))
+      else if (wxFileExists (wxFullPath))
       {
         imageIndex = GetImageIndex (svn_wc_status_unversioned, -1);
       }
@@ -895,100 +922,103 @@ FileListCtrl::UpdateFileList ()
       }
     }
 
-    InsertItem (i, values[COL_NAME], imageIndex);
 
-
-    // The item data will be used to sort the list:
-    SetItemData (i, (long)new svn::Status (status));    // The control now owns this data
-    // and must delete it in due course.
-
-    text = "";
-
-    if (status.isVersioned ())
+    // User want to see unversioned entries?
+    if (status.isVersioned() || m->ShowUnversioned)
     {
-      const svn::Entry & entry = status.entry ();
-      values[COL_REV].Printf ("%ld", entry.revision ());
-      values[COL_CMT_REV].Printf ("%ld", entry.cmtRev ());
+      InsertItem (i, values[COL_NAME], imageIndex);
 
-      values[COL_AUTHOR] = entry.cmtAuthor ();
 
-      // date formatting
-      values[COL_CMT_DATE] = FormatDateTime (entry.cmtDate ());
-      values[COL_TEXT_TIME] = FormatDateTime (entry.textTime ());
-      values[COL_PROP_TIME] = FormatDateTime (entry.propTime ());
+      // The item data will be used to sort the list:
+      SetItemData (i, (long)new svn::Status (status));    // The control now owns this data
+      // and must delete it in due course.
 
-      values[COL_URL] = entry.url ();
-      values[COL_REPOS] = entry.repos ();
-      values[COL_UUID] = entry.uuid ();
-      
-      wxString schedule;
-      switch (entry.schedule ())
+      if (status.isVersioned ())
       {
-      case svn_wc_schedule_add:
-        schedule = _("add");
+        const svn::Entry & entry = status.entry ();
+        values[COL_REV].Printf (wxT("%ld"), entry.revision ());
+        values[COL_CMT_REV].Printf (wxT("%ld"), entry.cmtRev ());
+
+        values[COL_AUTHOR] = Utf8ToLocal (entry.cmtAuthor ());
+
+        // date formatting
+        values[COL_CMT_DATE] = FormatDateTime (entry.cmtDate ());
+        values[COL_TEXT_TIME] = FormatDateTime (entry.textTime ());
+        values[COL_PROP_TIME] = FormatDateTime (entry.propTime ());
+
+        values[COL_URL] = Utf8ToLocal (entry.url ());
+        values[COL_REPOS] = Utf8ToLocal (entry.repos ());
+        values[COL_UUID] = Utf8ToLocal (entry.uuid ());
+
+        wxString schedule;
+        switch (entry.schedule ())
+        {
+        case svn_wc_schedule_add:
+          schedule = _("add");
+          break;
+        case svn_wc_schedule_delete:
+          schedule = _("delete");
+          break;
+        case svn_wc_schedule_replace:
+          schedule = _("replace");
+          break;
+        case svn_wc_schedule_normal:
+          break;
+        }
+        values[COL_SCHEDULE] = schedule;
+
+        if (entry.isCopied ())
+        {
+          wxString tmp (Utf8ToLocal (entry.copyfromUrl()));
+          values[COL_COPIED].Printf (wxT("%s, %ld"),
+            tmp.c_str (),
+            entry.copyfromRev ());
+        }
+
+        values[COL_CONFLICT_OLD] = Utf8ToLocal (entry.conflictOld ());
+        values[COL_CONFLICT_NEW] = Utf8ToLocal (entry.conflictNew ());
+        values[COL_CONFLICT_WRK] = Utf8ToLocal (entry.conflictWrk ());
+        values[COL_CHECKSUM] = Utf8ToLocal (entry.checksum ());
+      }
+      switch (status.textStatus ())
+      {
+      case svn_wc_status_none:
         break;
-      case svn_wc_schedule_delete:
-        schedule = _("delete");
+      case svn_wc_status_normal:
+        // empty text
+        if (status.reposTextStatus () == svn_wc_status_modified)
+          values[COL_TEXT_STATUS] = _("out of date");
         break;
-      case svn_wc_schedule_replace:
-        schedule = _("replace");
-        break;
-      case svn_wc_schedule_normal:
-        schedule = "";
+      default:
+        values[COL_TEXT_STATUS] =
+          StatusDescription (status.textStatus ());
         break;
       }
-      values[COL_SCHEDULE] = schedule;
-
-      if (entry.isCopied ())
+      switch (status.propStatus ())
       {
-        values[COL_COPIED].Printf ("%s, %ld", 
-                                  entry.copyfromUrl (),
-                                  entry.copyfromRev ());
+      case svn_wc_status_none:
+        break;
+      case svn_wc_status_normal:
+        // empty text
+        if (status.reposPropStatus () == svn_wc_status_modified)
+          values[COL_PROP_STATUS] = _("out of date");
+        break;
+      default:
+        values[COL_PROP_STATUS] =
+          StatusDescription (status.propStatus ());
+        break;
       }
 
-      values[COL_CONFLICT_OLD] = entry.conflictOld ();
-      values[COL_CONFLICT_NEW] = entry.conflictNew ();
-      values[COL_CONFLICT_WRK] = entry.conflictWrk ();
-      values[COL_CHECKSUM] = entry.checksum ();
-    }
-    switch (status.textStatus ())
-    {
-    case svn_wc_status_none:
-      break;
-    case svn_wc_status_normal:
-      // empty text 
-      if (status.reposTextStatus () == svn_wc_status_modified)
-        values[COL_TEXT_STATUS] = _("out of date");
-      break;
-    default:
-      values[COL_TEXT_STATUS] = 
-        StatusDescription (status.textStatus ());
-      break;
-    }
-    switch (status.propStatus ())
-    {
-    case svn_wc_status_none:
-      break;
-    case svn_wc_status_normal:
-      // empty text
-      if (status.reposPropStatus () == svn_wc_status_modified)
-        values[COL_PROP_STATUS] = _("out of date");
-      break;
-    default:
-      values[COL_PROP_STATUS] = 
-        StatusDescription (status.propStatus ());
-      break;
-    }
-
-    // set the text for all visible items
-    // (ignore column 0 since this is already set with
-    // InsertItem
-    for (int col=1; col<COL_COUNT; col++)
-    {
-      int index = m->ColumnIndex[col];
-      if (index != -1)
+      // set the text for all visible items
+      // (ignore column 0 since this is already set with
+      // InsertItem
+      for (int col=1; col<COL_COUNT; col++)
       {
-        SetItem (i, index, values[col]);
+        int index = m->ColumnIndex[col];
+        if (index != -1)
+        {
+          SetItem (i, index, values[col]);
+        }
       }
     }
   }
@@ -1000,11 +1030,11 @@ FileListCtrl::UpdateFileList ()
   wxLogStatus (_("Ready"),"");
 }
 
-void 
+void
 FileListCtrl::OnDoubleClick (wxMouseEvent & event)
 {
   int flag;
-  
+
   // Don't post if the click didn't hit anything
   if (HitTest (ScreenToClient (wxGetMousePosition ()), flag) >= 0)
     if (!PostMenuEvent (this, ID_Default_Action))
@@ -1012,7 +1042,7 @@ FileListCtrl::OnDoubleClick (wxMouseEvent & event)
 }
 
 
-void 
+void
 FileListCtrl::OnKeyDown (wxKeyEvent & event)
 {
   switch (event.GetKeyCode ())
@@ -1021,7 +1051,7 @@ FileListCtrl::OnKeyDown (wxKeyEvent & event)
       if (!PostMenuEvent (this, ID_Default_Action))
         event.Skip ();
       break;
-    
+
     default:
       event.Skip ();
       break;
@@ -1100,7 +1130,7 @@ FileListCtrl::ShowMenu (wxPoint & pt)
   // we are going to add filetype specific entries
   if (GetSelectedItemCount () == 1)
   {
-    long item = GetNextItem (-1, wxLIST_NEXT_ALL, 
+    long item = GetNextItem (-1, wxLIST_NEXT_ALL,
                              wxLIST_STATE_SELECTED);
     svn::Status * status = (svn::Status*)GetItemData (item);
 
@@ -1114,11 +1144,11 @@ FileListCtrl::ShowMenu (wxPoint & pt)
   // Check for disabled items
   RapidSvnFrame* frame = (RapidSvnFrame*) wxGetApp ().GetTopWindow ();
   frame->TrimDisabledMenuItems (menu);
-  
+
   PopupMenu (&menu, pt);
 }
 
-const IndexArray 
+const IndexArray
 FileListCtrl::GetSelectedItems () const
 {
   int sel = GetSelectedItemCount ();
@@ -1146,7 +1176,7 @@ FileListCtrl::GetSelectedItems () const
   return indx_arr;
 }
 
-const svn::Targets 
+const svn::Targets
 FileListCtrl::GetTargets () const
 {
   IndexArray arr = GetSelectedItems ();
@@ -1176,7 +1206,7 @@ FileListCtrl::GetSelectionActionFlags () const
   IndexArray arr = GetSelectedItems ();
   size_t i, counter = 0;
   unsigned int flags = 0;
-  
+
   for (i = 0; i < arr.GetCount (); i++)
   {
     const int index = arr.Item (i);
@@ -1206,7 +1236,7 @@ FileListCtrl::GetSelectionActionFlags () const
       }
     }
   }
-  
+
   if (counter)
   {
     flags |= counter == 1 ? Action::SINGLE_TARGET : Action::MULTIPLE_TARGETS;
@@ -1242,7 +1272,7 @@ FileListCtrl::DeleteItem (long item)
   wxListCtrl::DeleteItem (item);
 }
 
-void 
+void
 FileListCtrl::ResetColumns ()
 {
   for (int col=0; col < COL_COUNT; col++)
@@ -1258,6 +1288,7 @@ FileListCtrl::ResetColumns ()
     case COL_CONFLICT_OLD:
     case COL_CONFLICT_NEW:
     case COL_CONFLICT_WRK:
+    case COL_EXTENSION:
       visible = false;
       break;
 
@@ -1275,7 +1306,7 @@ FileListCtrl::ResetColumns ()
   }
 }
 
-void 
+void
 FileListCtrl::SetColumnImages ()
 {
   // Update the column titles to reflect the sort column.
@@ -1364,10 +1395,10 @@ FileListCtrl::UpdateColumns ()
   {
     DeleteColumn (0);
   }
-    
+
   while (GetColumnCount () < count)
   {
-    InsertColumn (0, "");
+    InsertColumn (0, wxEmptyString);
   }
 
   // Now set the captions and widths
@@ -1389,7 +1420,7 @@ FileListCtrl::UpdateColumns ()
   m->DirtyColumns = false;
 }
 
-void 
+void
 FileListCtrl::OnColumnEndDrag (wxListEvent & event)
 {
   int index = event.GetColumn ();
@@ -1419,7 +1450,7 @@ void
 FileListCtrl::SetColumnWidth (const int col, const int width)
 {
   m->ColumnWidth[col] = width;
-  
+
   int index = m->ColumnIndex[col];
   if (index != -1)
   {
@@ -1469,6 +1500,20 @@ FileListCtrl::GetWithUpdate () const
 }
 
 
+void
+FileListCtrl::SetShowUnversioned (bool value)
+{
+  m->ShowUnversioned = value;
+}
+
+
+bool
+FileListCtrl::GetShowUnversioned () const
+{
+  return m->ShowUnversioned;
+}
+
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
