@@ -13,7 +13,7 @@
 #ifndef _FILE_LIST_CONROL_H_INCLUDED_
 #define _FILE_LIST_CONROL_H_INCLUDED_
 
-// wxwindows
+// wxWidgets
 #include "wx/listctrl.h"
 #include "wx/dynarray.h"
 
@@ -60,6 +60,7 @@ public:
     COL_TEXT_STATUS,
     COL_PROP_STATUS,
     COL_CMT_DATE,
+    COL_EXTENSION,
     COL_TEXT_TIME,
     COL_PROP_TIME,
     COL_CHECKSUM,
@@ -87,7 +88,7 @@ public:
    * set visibility of column
    *
    * @param col column number
-   * @param visible 
+   * @param visible
    */
   void SetColumnVisible (const int col, const bool visible);
 
@@ -108,7 +109,7 @@ public:
    * set column width
    *
    * @param col column number
-   * @param width 
+   * @param width
    */
   void SetColumnWidth (const int col, const int width);
 
@@ -133,6 +134,14 @@ public:
   bool
   GetWithUpdate () const;
 
+  /**
+   * shall we display unversioned file entries?
+   */
+  void
+  SetShowUnversioned (bool value);
+
+  bool
+  GetShowUnversioned() const;
 
   /**
    * get the "flat" setting
