@@ -19,7 +19,7 @@
 #include "svncpp/url.hpp"
 #include "svncpp/wc.hpp"
 
-// wxwindows
+// wxWidgets
 #include "wx/wx.h"
 #include "wx/filename.h"
 #include "wx/dir.h"
@@ -62,76 +62,11 @@ enum
 
 static const unsigned int MAXLENGTH_BOOKMARK = 35;
 
-/**
- * beautify a path, that is too long, so not everything can be
- * displayed
- *
- * Examples:
- * 1. Local Unix path
- *    Before:  /home/users/xela/work/rapidsvn/src/svncpp
- *    After:   /...ork/rapidsvn/src/svncpp
- *
- * 2. Local Windows path
- *    Before:  d:\Documents and Settings\alex\Application Data
- *    After:   D:\...alex\Application Data
- * 
- * 3. Repository URL
- *    Before:  https://svn.collab.net/repos/rapidsvn/trunk/src/svncpp
- *    After:   https://...apidsvn/trunk/src/svncpp
- *
- * Jobs to do:
- * - Uppercase Windows drive letters
- * - shorten path while preserving root path/url
- *
- * @param path input path
- * @return beatified path
- */
-static wxString 
-TruncatePath (const wxString & path_)
-{
-  wxString path (BeautifyPath (path_));
-
-  if (path.length() <= MAXLENGTH_BOOKMARK)
-    return path;
-
-  size_t pos = path.Find (":");
-  wxString newPath;
-
-  pos++;
-  if (pos > 0)
-    newPath = path.Left (pos);
-
-
-  // Now add chars until a different char than
-  // / or \ appears
-  while (pos < path.Length ())
-  {
-    char c = path.GetChar (pos);
-
-    if ( (c == '/') || (c == '\\'))
-    {
-      newPath += c;
-      pos++;
-    }
-    else
-      break;
-  }
-
-  newPath += "...";
-
-  const int restPos = path.Length () - MAXLENGTH_BOOKMARK + 
-    newPath.Length ();
-
-  newPath += path.Mid (restPos);
-
-  return newPath;
-}
-
 
 static bool
 IsValidSeparator (const wxString & sep)
 {
-  return ((sep == "/") || (sep == "\\"));
+  return ((sep == wxT("/")) || (sep == wxT("\\")));
 }
 
 
@@ -145,7 +80,7 @@ public:
   wxImageList* imageList;
   Bookmarks bookmarks;
   svn::Context defaultContext;
-  
+
   Data (wxWindow * window, const wxPoint & pos, const wxSize & size)
     : window (window), listener (0)
   {
@@ -160,12 +95,12 @@ public:
     imageList->Add (wxIcon (modified_open_folder_xpm));
     imageList->Add (wxIcon (bookmark_xpm));
 
-    treeCtrl = new wxTreeCtrl (window, -1, pos, size, 
+    treeCtrl = new wxTreeCtrl (window, -1, pos, size,
                                wxTR_HAS_BUTTONS|wxTR_SINGLE);
     treeCtrl->AssignImageList (imageList);
 
     FolderItemData* data = new FolderItemData (FOLDER_TYPE_BOOKMARKS);
-    rootId = treeCtrl->AddRoot (_("Bookmarks"), FOLDER_IMAGE_COMPUTER, 
+    rootId = treeCtrl->AddRoot (_("Bookmarks"), FOLDER_IMAGE_COMPUTER,
                                     FOLDER_IMAGE_COMPUTER, data);
     treeCtrl->SetItemHasChildren (rootId, TRUE);
   }
@@ -179,10 +114,10 @@ public:
   GetPath ()
   {
     const wxTreeItemId id = treeCtrl->GetSelection ();
-  
+
     if(!id.IsOk())
     {
-      return "";
+      return wxEmptyString;
     }
 
     FolderItemData* data = GetItemData (id);
@@ -193,7 +128,7 @@ public:
   GetSelection () const
   {
     const wxTreeItemId id = treeCtrl->GetSelection ();
-  
+
     if(!id.IsOk())
     {
       return NULL;
@@ -206,13 +141,15 @@ public:
   }
 
   svn::Context *
-  GetContext () 
+  GetContext ()
   {
     const FolderItemData * data = GetSelection ();
     svn::Context * context = 0;
 
     if (data == 0)
+    {
       context = &defaultContext;
+    }
     else
     {
       bool ok = true;
@@ -220,6 +157,10 @@ public:
       {
         switch (data->getFolderType ())
         {
+        case FOLDER_TYPE_BOOKMARKS:
+          context = &defaultContext;
+          break;
+
         case FOLDER_TYPE_NORMAL:
           {
             wxTreeItemId id = data->GetId ();
@@ -256,6 +197,7 @@ public:
     const FolderItemData * data = GetSelection ();
     if (!data)
       return;
+
     const svn::Context * context = GetContext ();
 
     // create menu
@@ -280,7 +222,7 @@ public:
 
       if (context != 0)
       {
-        username = context->getUsername ();
+        username = Utf8ToLocal (context->getUsername ());
       }
 
       if (username.length () == 0)
@@ -304,11 +246,11 @@ public:
       AppendMenuItem (menu, ID_Update);
       AppendMenuItem (menu, ID_Commit);
     }
-    
+
     // Check for disabled items
     RapidSvnFrame* frame = (RapidSvnFrame*) wxGetApp ().GetTopWindow ();
     frame->TrimDisabledMenuItems (menu);
-  
+
     // show menu
     window->PopupMenu (&menu, pt);
   }
@@ -321,17 +263,17 @@ public:
 
     wxDir dir (path);
 
-    bool ok = dir.GetFirst(&filename, wxEmptyString, 
+    bool ok = dir.GetFirst(&filename, wxEmptyString,
                              wxDIR_DIRS);
     if(!dir.IsOpened ())
       return false;
-  
+
     if (!ok)
       return false;
-  
+
     while (ok)
     {
-      if (filename != svn::Wc::ADM_DIR_NAME)
+      if (filename != Utf8ToLocal (svn::Wc::ADM_DIR_NAME))
         return true;
       ok = dir.GetNext (&filename);
     }
@@ -359,9 +301,11 @@ public:
   {
     if (treeCtrl)
     {
-      // this deletes all children and
-      // all of the itemdata
+        // this deletes all children and
+        // all of the itemdata
+#ifndef __WXMAC__ //wxMac crashes here
       treeCtrl->Collapse (rootId);
+#endif
     }
   }
 
@@ -391,16 +335,16 @@ public:
 
         for(index = 0; index < count; index++)
         {
-          const wxString path (bookmarks.GetBookmark (index));
-          FolderItemData* data= new FolderItemData (FOLDER_TYPE_BOOKMARK, 
+          const wxString path
+              (bookmarks.GetBookmark (index));
+          FolderItemData* data= new FolderItemData (FOLDER_TYPE_BOOKMARK,
                                                     path, path, TRUE);
-          wxString label (TruncatePath (path));
-          wxTreeItemId newId = treeCtrl->AppendItem (parentId, label, 
-                                                     FOLDER_IMAGE_BOOKMARK, 
-                                                     FOLDER_IMAGE_BOOKMARK, 
+          wxTreeItemId newId = treeCtrl->AppendItem (parentId, path,
+                                                     FOLDER_IMAGE_BOOKMARK,
+                                                     FOLDER_IMAGE_BOOKMARK,
                                                      data);
           treeCtrl->SetItemHasChildren (newId, TRUE);
-          treeCtrl->SetItemImage (newId, FOLDER_IMAGE_BOOKMARK,  
+          treeCtrl->SetItemImage (newId, FOLDER_IMAGE_BOOKMARK,
                                     wxTreeItemIcon_Expanded);
         }
       }
@@ -411,19 +355,22 @@ public:
       try
       {
         const wxString& parentPath = parentData->getPath ();
+        std::string parentPathUtf8;
+        LocalToUtf8 (parentPath, parentPathUtf8);
 
-        if ( svn::Url::isValid (parentPath) )
+        if ( svn::Url::isValid (parentPathUtf8.c_str ()))
           RefreshRepository (parentPath, parentId);
         else
           RefreshLocal (parentPath, parentId);
       }
       catch (svn::ClientException & e)
       {
+        wxString errtxt (Utf8ToLocal (e.message ()));
         wxLogError(_("Error while refreshing filelist (%s)"),
-                    e.message ());
+                    errtxt.c_str ());
       }
       break;
-    }   
+    }
 
     treeCtrl->SortChildren (parentId);
   }
@@ -446,7 +393,7 @@ public:
   }
 
   void
-  RefreshLocal (const wxString & parentPath, 
+  RefreshLocal (const wxString & parentPath,
                 const wxTreeItemId & parentId)
   {
     svn::Client client (GetContext ());
@@ -455,30 +402,31 @@ public:
       return;
 
     wxString filename;
-    bool ok = dir.GetFirst(&filename, wxEmptyString, 
+    bool ok = dir.GetFirst(&filename, wxEmptyString,
                            wxDIR_DIRS);
     bool parentHasSubdirectories = false;
 
     while(ok)
     {
-      if(filename != svn::Wc::ADM_DIR_NAME)
+      if(filename != Utf8ToLocal (svn::Wc::ADM_DIR_NAME))
       {
         parentHasSubdirectories = true;
-  
+
         wxFileName path(parentPath, filename, wxPATH_NATIVE);
         wxString fullPath = path.GetFullPath ();
-        const char * fullPath_c = fullPath.c_str ();
+        std::string fullPathUtf8;
+        LocalToUtf8(fullPath, fullPathUtf8);
         int image = FOLDER_IMAGE_FOLDER;
         int open_image = FOLDER_IMAGE_OPEN_FOLDER;
 
-        if (!svn::Wc::checkWc (fullPath_c))
+        if (!svn::Wc::checkWc (fullPathUtf8.c_str ()))
         {
           image = FOLDER_IMAGE_NONSVN_FOLDER;
           open_image = FOLDER_IMAGE_NONSVN_OPEN_FOLDER;
         }
         else
         {
-          svn::Status status = client.singleStatus (fullPath_c);
+          svn::Status status = client.singleStatus (fullPathUtf8.c_str ());
           if ((status.textStatus () == svn_wc_status_modified) ||
               (status.propStatus () == svn_wc_status_modified))
           {
@@ -486,19 +434,19 @@ public:
             open_image = FOLDER_IMAGE_MODIFIED_OPEN_FOLDER;
           }
         }
-  
-        FolderItemData * data = 
-          new FolderItemData (FOLDER_TYPE_NORMAL, 
-                              fullPath, 
+
+        FolderItemData * data =
+          new FolderItemData (FOLDER_TYPE_NORMAL,
+                              fullPath,
                               filename, TRUE);
 
-        wxTreeItemId newId = 
+        wxTreeItemId newId =
           treeCtrl->AppendItem(
-            parentId, filename, 
+            parentId, filename,
             image, image, data);
         treeCtrl->SetItemHasChildren (
           newId, HasSubdirectories(fullPath) );
-        treeCtrl->SetItemImage (newId, open_image,  
+        treeCtrl->SetItemImage (newId, open_image,
                                 wxTreeItemIcon_Expanded);
       }
 
@@ -511,13 +459,15 @@ public:
   }
 
   void
-  RefreshRepository (const wxString & parentPath, 
+  RefreshRepository (const wxString & parentPath,
                      const wxTreeItemId & parentId)
   {
     svn::Client client (GetContext ());
     svn::Revision rev (svn::Revision::HEAD);
-    svn::DirEntries entries = 
-      client.ls (parentPath, rev, false);
+    std::string parentPathUtf8;
+    LocalToUtf8(parentPath, parentPathUtf8);
+    svn::DirEntries entries =
+      client.ls (parentPathUtf8.c_str (), rev, false);
     svn::DirEntries::const_iterator it;
 
     //bool parentHasSubdirectories = false;
@@ -527,27 +477,27 @@ public:
       int image = FOLDER_IMAGE_FOLDER;
       int open_image = FOLDER_IMAGE_OPEN_FOLDER;
 
-      wxString fullPath = entry.name ();
+      wxString fullPath = Utf8ToLocal (entry.name ());
       wxString filename (fullPath.Mid (parentPath.Length () + 1));
       //parentHasSubdirectories = true;
-      
+
       if (entry.kind () != svn_node_dir)
         continue;
 
-      FolderItemData * data = 
-        new FolderItemData (FOLDER_TYPE_NORMAL, 
-                            fullPath, 
+      FolderItemData * data =
+        new FolderItemData (FOLDER_TYPE_NORMAL,
+                            fullPath,
                             filename, TRUE);
 
-      wxTreeItemId newId = 
+      wxTreeItemId newId =
         treeCtrl->AppendItem(
-          parentId, filename, 
+          parentId, filename,
           image, image, data);
       treeCtrl->SetItemHasChildren (
         newId, true );
-      treeCtrl->SetItemImage (newId, open_image,  
+      treeCtrl->SetItemImage (newId, open_image,
                                 wxTreeItemIcon_Expanded);
-      
+
     }
   }
 
@@ -555,7 +505,7 @@ public:
   /**
    * Finds the child entry with @a path
    */
-  wxTreeItemId 
+  wxTreeItemId
   FindClosestChild (const wxTreeItemId & parentId, const wxString & path)
   {
     long cookie;
@@ -572,12 +522,12 @@ public:
       if (!data->isReal ())
         break;
 
-      const svn::Path nodePath (data->getPath ());
+      const svn::Path nodePath (LocalToUtf8(data->getPath ()));
       if (nodePath.length () == 0)
         break;
 
       // first check: full match?
-      if (path.IsSameAs (nodePath.c_str()))
+      if (path.IsSameAs (Utf8ToLocal (nodePath.c_str ())))
       {
         childId = id;
         break;
@@ -587,7 +537,7 @@ public:
       wxString prefix (path.Left (nodePath.length ()));
       wxString sep = path.Mid (nodePath.length (), 1);
 
-      if (prefix.IsSameAs (nodePath.c_str()) &&
+      if (prefix.IsSameAs (Utf8ToLocal (nodePath.c_str ())) &&
            IsValidSeparator (sep))
       {
         childId = id;
@@ -611,8 +561,13 @@ public:
    * @param path
    */
   bool
-  SelectFolder (const wxString & path)
+  SelectFolder (const wxString & pathP)
   {
+    // Convert the input string to subversion internal representation
+    std::string pathPUtf8;
+    LocalToUtf8 (pathP, pathPUtf8);
+    const wxString path = Utf8ToLocal (svn::Path (pathPUtf8).c_str());
+
     wxTreeItemId bookmarkId = GetSelectedBookmarkId ();
 
     // found a valid bookmark? otherwise quit
@@ -628,7 +583,7 @@ public:
 
       // first some validity checkings:
       // - there has to be a valid @a data item
-      // - the node has to be "real" 
+      // - the node has to be "real"
       // - the path of the node has to be non-empty
       // - the prefix of @a path has to match
       //   the path of the @a node
@@ -638,13 +593,13 @@ public:
       if (!data->isReal ())
         break;
 
-      svn::Path nodePath (data->getPath ());
+      const svn::Path nodePath (LocalToUtf8 (data->getPath ()));
       if (nodePath.length () == 0)
-       break;
+        break;
 
       // check if @a path and @a nodePath match already
       // in this case we are done
-      if (path.IsSameAs (nodePath.c_str()))
+      if (path.IsSameAs (Utf8ToLocal (nodePath.c_str())))
       {
         success = true;
         break;
@@ -652,7 +607,8 @@ public:
 
       wxString prefix (path.Left (nodePath.length ()));
       wxString sep (path.Mid (nodePath.length (), 1));
-      if ((!prefix.IsSameAs (nodePath.c_str())) || !IsValidSeparator (sep))
+      if ((!prefix.IsSameAs
+          (Utf8ToLocal (nodePath.c_str()))) || !IsValidSeparator (sep))
        break;
 
       if (!data->hasChildren ())
@@ -682,7 +638,7 @@ public:
   }
 
   bool
-  SelectBookmark (const char *bookmarkPath)
+  SelectBookmark (const wxString & bookmarkPath)
   {
     long cookie;
     wxTreeItemId id = treeCtrl->GetFirstChild (rootId, cookie);
@@ -718,11 +674,11 @@ public:
 
   /**
    * Try to go up in the folder hierarchy until we
-   * find a bookmark node. 
+   * find a bookmark node.
    *
    * @return id of bookmark for selected node
    */
-  wxTreeItemId 
+  wxTreeItemId
   GetSelectedBookmarkId () const
   {
     wxTreeItemId id = treeCtrl->GetSelection ();
@@ -750,12 +706,12 @@ public:
   }
 
 
-  wxString 
+  wxString
   GetSelectedBookmark () const
   {
     wxTreeItemId id = GetSelectedBookmarkId ();
 
-    wxString path ("");
+    wxString path;
 
     if (id.IsOk ())
     {
@@ -767,16 +723,16 @@ public:
 
     return path;
   }
-    
+
 };
 
 BEGIN_EVENT_TABLE (FolderBrowser, wxControl)
   EVT_TREE_ITEM_EXPANDING (-1, FolderBrowser::OnExpandItem)
   EVT_TREE_ITEM_COLLAPSED (-1, FolderBrowser::OnCollapseItem)
-  EVT_SIZE (FolderBrowser::OnSize) 
+  EVT_SIZE (FolderBrowser::OnSize)
   EVT_TREE_ITEM_RIGHT_CLICK (-1, FolderBrowser::OnItemRightClk)
   EVT_CONTEXT_MENU (FolderBrowser::OnContextMenu)
-END_EVENT_TABLE () 
+END_EVENT_TABLE ()
 
 FolderBrowser::FolderBrowser (wxWindow * parent, const wxWindowID id,
                               const wxPoint & pos, const wxSize & size,
@@ -831,7 +787,7 @@ FolderBrowser::RemoveBookmark ()
     {
       wxString path = data->getPath ();
       m->Delete (id);
-      m->bookmarks.RemoveBookmark (path.c_str ());
+      m->bookmarks.RemoveBookmark (path);
       success = TRUE;
     }
   }
@@ -840,13 +796,13 @@ FolderBrowser::RemoveBookmark ()
 }
 
 void
-FolderBrowser::AddBookmark (const char * path)
+FolderBrowser::AddBookmark (const wxString & path)
 {
   m->bookmarks.AddBookmark (path);
 }
 
 const
-wxString 
+wxString
 FolderBrowser::GetPath () const
 {
   return m->GetPath ();
@@ -903,7 +859,7 @@ FolderBrowser::OnItemRightClk (wxTreeEvent & event)
 #endif
 }
 
-void 
+void
 FolderBrowser::OnContextMenu (wxContextMenuEvent & event)
 {
   wxPoint clientPt = ScreenToClient (event.GetPosition ());
@@ -911,7 +867,7 @@ FolderBrowser::OnContextMenu (wxContextMenuEvent & event)
 }
 
 bool
-FolderBrowser::SelectFolder (const char * path)
+FolderBrowser::SelectFolder (const wxString & path)
 {
   return m->SelectFolder (path);
 }
@@ -922,13 +878,13 @@ FolderBrowser::GetBookmarkCount () const
   return m->bookmarks.Count ();
 }
 
-const char *
+const wxString &
 FolderBrowser::GetBookmark (const size_t index) const
 {
   return m->bookmarks.GetBookmark (index);
 }
 
-svn::Context * 
+svn::Context *
 FolderBrowser::GetContext ()
 {
   return m->GetContext ();
@@ -940,14 +896,14 @@ FolderBrowser::SetAuthPerBookmark (const bool value)
   m->bookmarks.SetAuthPerBookmark (value);
 }
 
-const bool 
+const bool
 FolderBrowser::GetAuthPerBookmark () const
 {
   return m->bookmarks.GetAuthPerBookmark ();
 }
 
 bool
-FolderBrowser::SelectBookmark (const char * bookmarkPath)
+FolderBrowser::SelectBookmark (const wxString & bookmarkPath)
 {
   return m->SelectBookmark (bookmarkPath);
 }
