@@ -13,7 +13,7 @@
 #ifndef _FOLDER_BROWSER_H_INCLUDED_
 #define _FOLDER_BROWSER_H_INCLUDED_
 
-// wxwindows
+// wxWidgets
 #include "wx/treectrl.h"
 
 // forward declarations
@@ -31,7 +31,7 @@ public:
   FolderBrowser (wxWindow * parent,  const wxWindowID id = -1,
                  const wxPoint & pos = wxDefaultPosition,
                  const wxSize & size = wxDefaultSize,
-                 const wxString & name = "FolderBrowser");
+                 const wxString & name = wxT("FolderBrowser"));
 
   virtual ~ FolderBrowser ();
 
@@ -43,14 +43,14 @@ public:
   const bool RemoveBookmark ();
 
   /**
-   * add bookmark 
+   * add bookmark
    */
-  void AddBookmark (const char * bookmarkPath);
+  void AddBookmark (const wxString & path);
 
   /**
    * @return bookmark count on bookmarks
    */
-  const size_t 
+  const size_t
   GetBookmarkCount () const;
 
   /**
@@ -59,7 +59,7 @@ public:
    * @param index zero-based index
    * @return path of the bookmark
    */
-  const char *
+  const wxString &
   GetBookmark (const size_t index) const;
 
   /**
@@ -94,16 +94,16 @@ public:
    * @retval false if entry was not found
    */
   bool
-  SelectFolder (const char * path);
+  SelectFolder (const wxString & path);
 
   /**
-   * selects the @a bookmark 
+   * selects the @a bookmark
    *
    * @param bookmarkPath bookmark path
    * @return true on success
    */
   bool
-  SelectBookmark (const char * bookmarkPath);
+  SelectBookmark (const wxString & bookmarkPath);
 
   /**
    * setting whether there will be one login for all the
@@ -117,7 +117,7 @@ public:
   /**
    * @return auth per bookmark setting
    */
-  const bool 
+  const bool
   GetAuthPerBookmark () const;
 
 
@@ -133,7 +133,7 @@ private:
   Data * m;
 
   /**
-   * disallow default constructor 
+   * disallow default constructor
    */
   FolderBrowser ();
 
@@ -157,7 +157,7 @@ private:
   void OnCollapseItem (wxTreeEvent & event);
 
   void OnItemRightClk (wxTreeEvent & event);
-  
+
   void OnContextMenu (wxContextMenuEvent & event);
 
 };
