@@ -13,7 +13,7 @@
 #ifndef _IDS_H_INCLUDED_
 #define _IDS_H_INCLUDED_
 
-// wxwindows
+// wxWidgets
 #include "wx/defs.h"
 
 /*
@@ -26,7 +26,10 @@ enum
   ID_About,
   ID_Refresh,
   ID_RefreshWithUpdate,
-  ID_Contents,
+  ID_ShowUnversioned,
+  ID_HelpContents,
+  ID_HelpIndex,
+  ID_HelpStartupTips,
   ID_Preferences,
   ID_AddWcBookmark,
   ID_AddRepoBookmark,
@@ -51,6 +54,8 @@ enum
   ID_Default_Action,
   ID_Delete,
   ID_Diff,
+  ID_DiffBase,
+  ID_DiffHead,
   ID_Explore,
   ID_Import,
   ID_Log,
@@ -79,6 +84,7 @@ enum
   ID_Column_Text_Status,
   ID_Column_Prop_Status,
   ID_Column_Cmt_Date,
+  ID_Column_Extension,
   ID_Column_Text_Time,
   ID_Column_Prop_Time,
   ID_Column_Url,
