@@ -11,7 +11,7 @@
  * ====================================================================
  */
 
-// wxwindows
+// wxWidgets
 #include "wx/wx.h"
 #include "wx/valgen.h"
 
@@ -54,7 +54,7 @@ MergeDlg::TestRev (wxString & val)
 }
 
 MergeDlg::MergeDlg (wxWindow * parent, bool calledByLogDlg, MergeData & data)
-           : wxDialog (parent, -1, _("Merge revisions"), wxDefaultPosition, 
+           : wxDialog (parent, -1, _("Merge revisions"), wxDefaultPosition,
              wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER),
              m_data(data), m_calledByLogDlg (calledByLogDlg)
 {
@@ -73,7 +73,7 @@ MergeDlg::OnOK (wxCommandEvent & event)
   TrimString (m_data.Path2);
   TrimString (m_data.Path2Rev);
   TrimString (m_data.Destination);
-  
+
   // test revision numbers
   if (TestRev (m_data.Path1Rev) < 0)
     return;
@@ -86,28 +86,28 @@ MergeDlg::OnOK (wxCommandEvent & event)
     wxMessageBox (_("First path or URL is required for merge!"),
                   _("Error"), wxOK | wxCENTRE | wxICON_ERROR);
 
-    // Do not allow the user to continue if the path is empty 
+    // Do not allow the user to continue if the path is empty
     // and the import is addressing a file.
     return;
   }
 
-  // If start revision for first path is emtpy... 
+  // If start revision for first path is emtpy...
   // (the end revision should be empty also in this case - checked above)
   if (m_data.Path1Rev.IsEmpty ())
   {
-    // the second path should be specified, as now there is 
+    // the second path should be specified, as now there is
     // no deductible interval from the first path
     if (m_data.Path2.IsEmpty ())
     {
       wxMessageBox (_("Second path or URL is required for merge!"),
                     _("Error"), wxOK | wxCENTRE | wxICON_ERROR);
 
-      // Do not allow the user to continue if the path is empty 
+      // Do not allow the user to continue if the path is empty
       // and the import is addressing a file.
       return;
     }
   }
-  
+
   wxDialog::OnOK(event);
 }
 
@@ -119,40 +119,40 @@ MergeDlg::InitializeData ()
   // Merge paths grid:
   wxStaticBoxSizer *mergeSizer = new wxStaticBoxSizer(
     new wxStaticBox(this, -1, _("Merge")), wxHORIZONTAL);
-    
+
   wxFlexGridSizer* grid = new wxFlexGridSizer(6, 2, 0, 0);
   grid->AddGrowableCol(0);  // The first column can be expanded.
 
-  // Row 0:  
-  grid->Add(new wxStaticText(this, -1, _("First working copy or URL")), 0, 
+  // Row 0:
+  grid->Add(new wxStaticText(this, -1, _("First working copy or URL")), 0,
     0, 5);
-  grid->Add(new wxStaticText(this, -1, _("Revision")), 0, 
+  grid->Add(new wxStaticText(this, -1, _("Revision")), 0,
     wxLEFT | wxALIGN_CENTER_VERTICAL, 20);
-    
-  // Row 1:  
-  wxTextCtrl *Path1 = new wxTextCtrl(this, -1, "",
+
+  // Row 1:
+  wxTextCtrl *Path1 = new wxTextCtrl(this, -1, wxEmptyString,
     wxDefaultPosition, wxSize(300, -1), 0,
     wxTextValidator(wxFILTER_NONE, &m_data.Path1));
   grid->Add(Path1, 1, wxBOTTOM | wxEXPAND, 10);
-  
-  wxTextCtrl *Path1Rev = new wxTextCtrl(this, -1, "",
+
+  wxTextCtrl *Path1Rev = new wxTextCtrl(this, -1, wxEmptyString,
     wxDefaultPosition, wxDefaultSize, 0,
     wxTextValidator(wxFILTER_NUMERIC, &m_data.Path1Rev));
   grid->Add(Path1Rev, 0, wxLEFT, 20);
-    
+
   // Row 2:
-  grid->Add(new wxStaticText(this, -1, _("Second working copy or URL")), 0, 
+  grid->Add(new wxStaticText(this, -1, _("Second working copy or URL")), 0,
     0, 5);
-  grid->Add(new wxStaticText(this, -1, _("Revision")), 0, 
+  grid->Add(new wxStaticText(this, -1, _("Revision")), 0,
     wxLEFT | wxALIGN_CENTER_VERTICAL, 20);
 
-  // Row 3:  
-  wxTextCtrl *Path2 = new wxTextCtrl(this, -1, "",
+  // Row 3:
+  wxTextCtrl *Path2 = new wxTextCtrl(this, -1, wxEmptyString,
     wxDefaultPosition, wxDefaultSize, 0,
     wxTextValidator(wxFILTER_NONE, &m_data.Path2));
   grid->Add(Path2, 1, wxBOTTOM | wxEXPAND, 10);
 
-  wxTextCtrl *Path2Rev = new wxTextCtrl(this, -1, "",
+  wxTextCtrl *Path2Rev = new wxTextCtrl(this, -1, wxEmptyString,
     wxDefaultPosition, wxDefaultSize, 0,
     wxTextValidator(wxFILTER_NUMERIC, &m_data.Path2Rev));
   grid->Add(Path2Rev, 0, wxLEFT, 20);
@@ -162,11 +162,11 @@ MergeDlg::InitializeData ()
     grid->Add(new wxStaticText(this, -1, _("Destination file")), 0, 0, 5);
   else
     grid->Add(new wxStaticText(this, -1, _("Destination path")), 0, 0, 5);
-  grid->Add(new wxStaticText(this, -1, ""), 0, 
+  grid->Add(new wxStaticText(this, -1, wxEmptyString), 0,
     wxLEFT | wxALIGN_CENTER_VERTICAL, 20);
 
   // Row 5:
-  wxTextCtrl *Destination = new wxTextCtrl(this, -1, "",
+  wxTextCtrl *Destination = new wxTextCtrl(this, -1, wxEmptyString,
     wxDefaultPosition, wxDefaultSize, 0,
     wxTextValidator(wxFILTER_NONE, &m_data.Destination));
   grid->Add(Destination, 1, wxBOTTOM | wxEXPAND, 5);
@@ -181,7 +181,7 @@ MergeDlg::InitializeData ()
     Path2Rev->Disable();
   }
 
-  wxButton* BrowseButton = new wxButton(this, ID_BUTTON_BROWSE, "...", 
+  wxButton* BrowseButton = new wxButton(this, ID_BUTTON_BROWSE, wxT("..."),
     wxPoint(-1,-1), wxSize(20, -1));
   grid->Add(BrowseButton, 0, wxALL, 5);
 
@@ -198,9 +198,9 @@ MergeDlg::InitializeData ()
 
   // Button row
   wxBoxSizer *buttonSizer = new wxBoxSizer(wxHORIZONTAL);
-  buttonSizer->Add(new wxButton(this, wxID_OK, _("OK" )), 0, 
+  buttonSizer->Add(new wxButton(this, wxID_OK, _("OK" )), 0,
     wxALL, 10);
-  buttonSizer->Add(new wxButton(this, wxID_CANCEL, _("Cancel")), 0, 
+  buttonSizer->Add(new wxButton(this, wxID_CANCEL, _("Cancel")), 0,
     wxALL, 10);
 
   // Add all sizers to main sizer
