@@ -14,14 +14,15 @@
 // svncpp
 #include "svncpp/client.hpp"
 
-// wxwindows
-#include "wx/intl.h"
+// wxWidgets
+#include "wx/wx.h"
 
 // app
 #include "destination_dlg.hpp"
 #include "mkdir_action.hpp"
+#include "utils.hpp"
 
-MkdirAction::MkdirAction (wxWindow * parent, const char * path)
+MkdirAction::MkdirAction (wxWindow * parent, const wxString & path)
  : Action (parent, _("Mkdir"), GetBaseFlags ()),
    m_path (path)
 {
@@ -43,7 +44,7 @@ MkdirAction::Prepare ()
     return false;
   }
 
-  wxString target (dlg.GetDestination ()); 
+  wxString target (dlg.GetDestination ());
   m_target = target.Strip (wxString::both);
   return true;
 }
@@ -55,9 +56,12 @@ MkdirAction::Perform ()
 
   // add target to path
   wxString newDir (m_path + m_target);
+  // TODO: What is newDir for???
 
-  svn::Path target (m_path.c_str ());
-  target.addComponent (m_target.c_str ());
+  std::string pathUtf8 (LocalToUtf8 (m_path));
+  std::string targetUtf8 (LocalToUtf8 (m_target));
+  svn::Path target (pathUtf8);
+  target.addComponent (targetUtf8);
 
   client.mkdir (target, "");
   return true;
