@@ -30,7 +30,7 @@ public:
    * @param path path in which the directory is to
    *             be created
    */
-  MkdirAction (wxWindow * parent, const char * path);
+  MkdirAction (wxWindow * parent, const wxString & path);
 
   virtual bool Perform ();
   virtual bool Prepare ();
@@ -40,7 +40,9 @@ public:
    */
   static unsigned int GetBaseFlags ()
   {
-    return SINGLE_TARGET|MULTIPLE_TARGETS|RESPOSITORY_TYPE|VERSIONED_WC_TYPE|UNVERSIONED_WC_TYPE;
+    return SINGLE_TARGET| MULTIPLE_TARGETS|
+           RESPOSITORY_TYPE| VERSIONED_WC_TYPE| UNVERSIONED_WC_TYPE|
+           UPDATE_TREE;
   }
 };
 
