@@ -13,27 +13,53 @@
 #ifndef _RAPIDSVN_APP_H_INCLUDED_
 #define _RAPIDSVN_APP_H_INCLUDED_
 
-// wxwindows
+// wxWidgets
 #include "wx/app.h"
 #include "wx/intl.h"
+#include <wx/html/helpctrl.h> // html help support
+
+class wxTipProvider;
 
 class RapidSvnApp:public wxApp
 {
 public:
-  void OptionallyRegisterTempFile (const char* filename);
+  void OptionallyRegisterTempFile (const wxString & filename);
   void OptionallyPurgeTempFiles ();
-  
+
+#if wxUSE_WXHTML_HELP
+  wxHtmlHelpController& GetHelpController()
+  {
+    return *m_helpController;
+  }
+#endif
+
+#if wxUSE_STARTUP_TIPS
+  wxTipProvider*
+  MakeTipProvider (bool force = false);
+
+  void
+  SaveTipsInfo (bool showAtStartup, int tipIndex);
+#endif
+
 protected:
   virtual bool OnInit ();
   virtual int OnExit ();
-  
+
 private:
   wxLocale m_locale;
-  
+
   wxArrayString m_TempFiles;
+
+#if wxUSE_WXHTML_HELP
+  wxHtmlHelpController* m_helpController;
+
+  bool
+  LocateHelp ();
+#endif
 };
 
 DECLARE_APP (RapidSvnApp)
+
 #endif
 /* -----------------------------------------------------------------
  * local variables:
