@@ -10,10 +10,11 @@
  * history and logs, available at http://rapidsvn.tigris.org/.
  * ====================================================================
  */
-// wxwindows
+// wxWidgets
 #include "wx/confbase.h"
 #include "wx/wx.h"
 #include "wx/filename.h"
+#include <wx/tipdlg.h>
 
 // svncpp
 #include "svncpp/apr.hpp"
@@ -24,6 +25,7 @@
 #include "svncpp/wc.hpp"
 
 // app
+#include "rapidsvn_app.hpp"
 #include "config.hpp"
 #include "diff_data.hpp"
 #include "ids.hpp"
@@ -86,19 +88,19 @@
 static const int NUM_ITEMS = 30;
 
 // List config keys here, to avoid duplicating literal text:
-const static char ConfigLeft[] = "/MainFrame/Left";
-const static char ConfigTop[] = "/MainFrame/Top";
-const static char ConfigWidth[] = "/MainFrame/Width";
-const static char ConfigHeight[] = "/MainFrame/Height";
-const static char ConfigMaximized[] = "/MainFrame/Maximized";
-const static char ConfigSplitterHoriz[] = "/MainFrame/SplitterHoriz";
-const static char ConfigSplitterVert[] = "/MainFrame/SplitterVert";
-const static char ConfigBookmarkFmt[] = "/Bookmarks/Bookmark%ld";
-const static char ConfigBookmarkCount[] = "/Bookmarks/Count";
+const static wxChar ConfigLeft[] = wxT("/MainFrame/Left");
+const static wxChar ConfigTop[] = wxT("/MainFrame/Top");
+const static wxChar ConfigWidth[] = wxT("/MainFrame/Width");
+const static wxChar ConfigHeight[] = wxT("/MainFrame/Height");
+const static wxChar ConfigMaximized[] = wxT("/MainFrame/Maximized");
+const static wxChar ConfigSplitterHoriz[] = wxT("/MainFrame/SplitterHoriz");
+const static wxChar ConfigSplitterVert[] = wxT("/MainFrame/SplitterVert");
+const static wxChar ConfigBookmarkFmt[] = wxT("/Bookmarks/Bookmark%ld");
+const static wxChar ConfigBookmarkCount[] = wxT("/Bookmarks/Count");
 
-const static char TraceMisc[] = "tracemisc";
+const static wxChar TraceMisc[] = wxT("tracemisc");
 
-// Platform specific constants. 
+// Platform specific constants.
 #ifdef __WXMSW__
   const static int SPLITTER_STYLE = wxSP_FULLSASH | wxSP_LIVE_UPDATE | wxCLIP_CHILDREN;
 #else
@@ -123,6 +125,7 @@ static const int COLUMN_ID_MAP[FileListCtrl::COL_COUNT] =
   ID_Column_Text_Status,
   ID_Column_Prop_Status,
   ID_Column_Cmt_Date,
+  ID_Column_Extension,
   ID_Column_Text_Time,
   ID_Column_Prop_Time,
   ID_Column_Checksum,
@@ -130,7 +133,7 @@ static const int COLUMN_ID_MAP[FileListCtrl::COL_COUNT] =
   ID_Column_Repos,
   ID_Column_Uuid,
   ID_Column_Schedule,
-  ID_Column_Copied, 
+  ID_Column_Copied,
   ID_Column_ConflictOld,
   ID_Column_ConflictNew,
   ID_Column_ConflictWrk
@@ -141,17 +144,18 @@ static const int COLUMN_ID_MAP[FileListCtrl::COL_COUNT] =
  * the column headings in FileListCtrl since they dont have
  * shortcuts.
  */
-static const char *
+static const wxChar *
 COLUMN_CAPTIONS[FileListCtrl::COL_COUNT] =
 {
-  "", // Name is not used here
-  "", // Path is not used here
+  wxT(""), // Name is not used here
+  wxT(""), // Path is not used here
   _("&Revision"),
   _("R&ep. Rev."),
   _("&Author"),
   _("&Status"),
   _("&Prop Status"),
   _("&Last Changed"),
+  _("E&xtension"),
   _("&Date"),
   _("Pr&op Date"),
   _("Checksum"),
@@ -183,6 +187,25 @@ CreateActionWorker (wxWindow * parent)
 }
 
 
+class LogTracer:public wxTextCtrl, public Tracer
+{
+
+public:
+  LogTracer (wxWindow * parent)
+    : wxTextCtrl (parent, -1, wxEmptyString,
+                  wxPoint (0, 0), wxDefaultSize,
+                  wxTE_MULTILINE | wxTE_READONLY)
+  {
+    SetMaxLength (0);
+  }
+
+  void Trace (const wxString & str)
+  {
+    AppendText (str + wxT("\n"));
+  }
+};
+
+
 /**
  * class that hide implementation specific data and methods from
  * the interface
@@ -195,6 +218,7 @@ public:
   Listener listener;
   bool updateAfterActivate;
   bool dontUpdateFilelist;
+  const wxLocale & locale;
 private:
   bool m_running;
   size_t m_toolbar_rows;        // 1 or 2 only (toolbar rows)
@@ -202,15 +226,16 @@ private:
 
 public:
 
-  /** 
-   * This instance of @a apr is used to initialize/terminate apr 
+  /**
+   * This instance of @a apr is used to initialize/terminate apr
    */
   svn::Apr apr;
 
-  Data (wxFrame * parent)
+  Data (wxFrame * parent, const wxLocale & locale_)
     : MenuColumns (0), MenuBar (0), listener (parent),
       updateAfterActivate (false), dontUpdateFilelist (false),
-      m_running (false), m_toolbar_rows (1), m_parent (parent)
+      locale (locale_), m_running (false), m_toolbar_rows (1),
+      m_parent (parent)
   {
     InitializeMenu ();
   }
@@ -218,10 +243,22 @@ public:
   void
   InitializeMenu ()
   {
+
+    // the following code places the menu items in their correct
+    // places on MacOSX:
+#ifdef __WXMAC__
+    wxApp::s_macAboutMenuItemId = ID_About;
+    wxApp::s_macPreferencesMenuItemId = ID_Preferences;
+    wxApp::s_macHelpMenuTitleName = _("&Help");
+#endif
+
     // File menu
     wxMenu *menuFile = new wxMenu;
+    // Quit menu item is not necessary on MacOSX:
+#ifndef __WXMAC__
     //menuFile->AppendSeparator ();
     AppendMenuItem (*menuFile, ID_Quit);
+#endif
 
     // Columns menu
     MenuColumns = new wxMenu;
@@ -249,9 +286,13 @@ public:
     menuView->Append (0, _("Columns"), MenuColumns);
     menuView->AppendCheckItem (ID_Flat, _("Flat Mode"));
     menuView->AppendCheckItem (ID_RefreshWithUpdate, _("Refresh with Update"));
+    menuView->AppendCheckItem (ID_ShowUnversioned, _("Show unversioned entries"));
 
+    // Preferences menu item goes to its own place on MacOSX,
+    // so no separator is necessary.
+#ifndef __WXMAC__
     menuView->AppendSeparator ();
-    
+#endif
     AppendMenuItem (*menuView, ID_Preferences);
 
     // Repository menu
@@ -283,14 +324,24 @@ public:
 
     // Help Menu
     wxMenu *menuHelp = new wxMenu;
-    //dont lie about not existant help!
-    //menuHelp->Append (ID_Contents, _("&Contents"));
-    //menuHelp->AppendSeparator ();
+
+#ifdef  USE_HTML_HELP
+    menuHelp->Append (ID_HelpContents, _("&Contents\tF1"));
+    menuHelp->Append (ID_HelpIndex, _("&Index\tShift+F1"));
+    menuHelp->AppendSeparator ();
+#endif
+#ifdef USE_STARTUP_TIPS
+    menuHelp->Append (ID_HelpStartupTips, _("Show Startup Tips"));
+    menuHelp->AppendSeparator ();
+#endif
     menuHelp->Append (ID_About, _("&About..."));
 
     // Create the menu bar and append the menus
     MenuBar = new wxMenuBar;
-    MenuBar->Append (menuFile, _("&File"));
+    // Under wxMac the menu might be empty, so
+    // don't show it:
+    if (menuFile->GetMenuItemCount()>0)
+      MenuBar->Append (menuFile, _("&File"));
     MenuBar->Append (menuView, _("&View"));
     MenuBar->Append (menuRepos, _("&Repository"));
     MenuBar->Append (menuModif, _("&Modify"));
@@ -300,13 +351,13 @@ public:
     MenuBar->Append (menuHelp, _("&Help"));
   }
 
-  bool 
+  bool
   IsColumnChecked (int id)
   {
     return MenuColumns->IsChecked (id);
   }
 
-  void 
+  void
   CheckColumn (int id, bool check)
   {
     MenuColumns->Check (id, check);
@@ -340,7 +391,7 @@ public:
     MenuBar->Enable (ID_Stop, running);
   }
 
-  bool 
+  bool
   IsRunning () const
   {
     return m_running;
@@ -372,8 +423,8 @@ public:
                       FALSE,
                       -1,
                       -1,
-                      (wxObject *) NULL, 
-                      _("Refresh"), 
+                      (wxObject *) NULL,
+                      _("Refresh"),
                       _("Refresh the file list"));
 
     toolBar->AddSeparator ();
@@ -389,8 +440,8 @@ public:
                       _("Stop"),
                       _("Stop the current action"));
 
-    // After adding the buttons to the toolbar, 
-    // must call Realize() to reflect the changes.  
+    // After adding the buttons to the toolbar,
+    // must call Realize() to reflect the changes.
     toolBar->Realize ();
 
     toolBar->SetRows (m_toolbar_rows);
@@ -499,16 +550,20 @@ BEGIN_EVENT_TABLE (RapidSvnFrame, wxFrame)
   EVT_MENU (ID_RemoveBookmark, RapidSvnFrame::OnRemoveBookmark)
   EVT_MENU (ID_Quit, RapidSvnFrame::OnQuit)
   EVT_MENU (ID_About, RapidSvnFrame::OnAbout)
-  
+
   EVT_MENU (ID_Info, RapidSvnFrame::OnInfo)
   EVT_UPDATE_UI (ID_Info, RapidSvnFrame::OnUpdateCommand)
 
-  EVT_MENU (ID_Contents, RapidSvnFrame::OnContents)
+  EVT_MENU (ID_HelpContents, RapidSvnFrame::OnHelpContents)
+  EVT_MENU (ID_HelpIndex, RapidSvnFrame::OnHelpIndex)
+  EVT_MENU (ID_HelpStartupTips, RapidSvnFrame::OnHelpStartupTips)
+
   EVT_MENU (ID_Preferences, RapidSvnFrame::OnPreferences)
   EVT_MENU (ID_Refresh, RapidSvnFrame::OnRefresh)
   EVT_MENU (ID_Column_Reset, RapidSvnFrame::OnColumnReset)
   EVT_MENU (ID_Flat, RapidSvnFrame::OnFlatView)
   EVT_MENU (ID_RefreshWithUpdate, RapidSvnFrame::OnRefreshWithUpdate)
+  EVT_MENU (ID_ShowUnversioned, RapidSvnFrame::OnShowUnversioned)
   EVT_MENU (ID_Login, RapidSvnFrame::OnLogin)
   EVT_MENU (ID_Logout, RapidSvnFrame::OnLogout)
   EVT_MENU (ID_Stop, RapidSvnFrame::OnStop)
@@ -519,21 +574,22 @@ BEGIN_EVENT_TABLE (RapidSvnFrame, wxFrame)
 
   EVT_UPDATE_UI_RANGE (ID_File_Min, ID_File_Max, RapidSvnFrame::OnUpdateCommand)
   EVT_UPDATE_UI_RANGE (ID_Verb_Min, ID_Verb_Max, RapidSvnFrame::OnUpdateCommand)
-  
+
   EVT_MENU (ACTION_EVENT, RapidSvnFrame::OnActionEvent)
 
   EVT_TOOL_ENTER (ID_TOOLBAR, RapidSvnFrame::OnToolEnter)
   EVT_TREE_SEL_CHANGED (-1, RapidSvnFrame::OnFolderBrowserSelChanged)
-  EVT_TREE_KEY_DOWN (-1, RapidSvnFrame::OnFolderBrowserKeyDown) 
+  EVT_TREE_KEY_DOWN (-1, RapidSvnFrame::OnFolderBrowserKeyDown)
   EVT_LIST_ITEM_SELECTED (-1, RapidSvnFrame::OnFileListSelected)
 END_EVENT_TABLE ()
 
 /** class implementation **/
-RapidSvnFrame::RapidSvnFrame (const wxString & title)
-  : wxFrame ((wxFrame *) NULL, -1, title, wxDefaultPosition, wxDefaultSize, 
+RapidSvnFrame::RapidSvnFrame (const wxString & title,
+                              const wxLocale & locale)
+  : wxFrame ((wxFrame *) NULL, -1, title, wxDefaultPosition, wxDefaultSize,
              wxDEFAULT_FRAME_STYLE)
 {
-  m = new Data (this);
+  m = new Data (this, locale);
   m_folder_browser = NULL;
   m_listCtrl = NULL;
   m_title = title;
@@ -561,20 +617,20 @@ RapidSvnFrame::RapidSvnFrame (const wxString & title)
   m->RecreateToolbar ();
   m->SetRunning (false);
 
-  m_horiz_splitter = 
+  m_horiz_splitter =
     new ProportionalSplitterWindow (1.0f, this,
                                     SPLITTER_WINDOW,
                                     wxDefaultPosition,
                                     wxDefaultSize,
                                     SPLITTER_STYLE);
 
+  m_info_panel = new wxPanel (m_horiz_splitter, -1,
+                              wxDefaultPosition, wxDefaultSize,
+                              wxTAB_TRAVERSAL | wxCLIP_CHILDREN);
 
-  m_info_panel = new InfoPanel (m_horiz_splitter);
-  m_log = new wxTextCtrl (m_horiz_splitter,
-                          -1,
-                          "",
-                          wxPoint (0, 0),
-                          wxDefaultSize, wxTE_MULTILINE | wxTE_READONLY);
+  m_log = new wxTextCtrl (m_horiz_splitter, -1, wxEmptyString,
+                          wxPoint (0, 0), wxDefaultSize,
+                          wxTE_MULTILINE | wxTE_READONLY);
 
   // as much as the widget can stand
   m_log->SetMaxLength (0);
@@ -590,11 +646,12 @@ RapidSvnFrame::RapidSvnFrame (const wxString & title)
                                           SPLITTER_STYLE);
 
   // Create the list control to display files
-  m_listCtrl = new FileListCtrl (m_vert_splitter, FILELIST_CTRL, 
+  m_listCtrl = new FileListCtrl (m_vert_splitter, FILELIST_CTRL,
                                  wxDefaultPosition, wxDefaultSize);
 
   m->CheckMenu (ID_Flat,              m_listCtrl->IsFlat());
   m->CheckMenu (ID_RefreshWithUpdate, m_listCtrl->GetWithUpdate());
+  m->CheckMenu (ID_ShowUnversioned,   m_listCtrl->GetShowUnversioned());
 
   // Create the browse control
   m_folder_browser = new FolderBrowser (m_vert_splitter, FOLDER_BROWSER);
@@ -699,7 +756,7 @@ RapidSvnFrame::~RapidSvnFrame ()
     wxString key;
     key.Printf (ConfigBookmarkFmt, item);
 
-    const char * bookmark = m_folder_browser->GetBookmark (item);
+    const wxString & bookmark = m_folder_browser->GetBookmark (item);
 
     pConfig->Write (key, bookmark);
   }
@@ -731,9 +788,9 @@ RapidSvnFrame::UpdateFileList ()
       }
       catch (svn::ClientException & e)
       {
-        wxString msg;
+        wxString msg, errtxt (Utf8ToLocal (e.message ()));
         msg.Printf (_("Error while updating filelist (%s)"),
-                    e.message ());
+                    errtxt.c_str ());
         Trace (msg);
 
         // probably unversioned resource
@@ -776,7 +833,7 @@ RapidSvnFrame::OnQuit (wxCommandEvent & WXUNUSED (event))
 void
 RapidSvnFrame::OnAbout (wxCommandEvent & WXUNUSED (event))
 {
-  AboutDlg dlg (this);
+  AboutDlg dlg (this, m->locale);
 
   dlg.ShowModal ();
 }
@@ -788,9 +845,48 @@ RapidSvnFrame::OnInfo (wxCommandEvent & WXUNUSED (event))
 }
 
 void
-RapidSvnFrame::OnContents (wxCommandEvent & WXUNUSED (event))
+RapidSvnFrame::OnHelpContents (wxCommandEvent & WXUNUSED (event))
 {
-  //TODO 
+#ifdef  USE_HTML_HELP
+  ::wxGetApp ().GetHelpController().DisplayContents();
+#endif
+}
+
+void
+RapidSvnFrame::OnHelpIndex (wxCommandEvent & WXUNUSED (event))
+{
+#ifdef  USE_HTML_HELP
+  ::wxGetApp ().GetHelpController().DisplayIndex();
+#endif
+}
+
+void
+RapidSvnFrame::OnHelpStartupTips (wxCommandEvent & WXUNUSED (event))
+{
+#ifdef USE_STARTUP_TIPS
+  RapidSvnApp& app = ::wxGetApp();
+  wxTipProvider* tipProvider = app.MakeTipProvider (true);
+  if (tipProvider)
+  {
+    bool showAtStartup = ::wxShowTip (this, tipProvider);
+    app.SaveTipsInfo (showAtStartup, tipProvider->GetCurrentTip ());
+    delete tipProvider;
+  }
+#endif
+}
+
+void RapidSvnFrame::OnHelp (wxCommandEvent &WXUNUSED(event))
+{
+#ifdef  USE_HTML_HELP
+    wxWindow *active = wxGetActiveWindow();
+    wxString helptext;
+    while (active && helptext.IsEmpty())
+    {
+        helptext = active->GetHelpText();
+        active = GetParent();
+    }
+    wxGetApp ().GetHelpController().Display(helptext);
+#endif
 }
 
 void
@@ -806,7 +902,7 @@ RapidSvnFrame::OnRefresh (wxCommandEvent & WXUNUSED (event))
 }
 
 
-void 
+void
 RapidSvnFrame::OnActivate (wxActivateEvent & event)
 {
   if (event.GetActive () && m->updateAfterActivate)
@@ -815,6 +911,11 @@ RapidSvnFrame::OnActivate (wxActivateEvent & event)
 
     UpdateFileList ();
   }
+
+  // wxMac needs this, otherwise the menu doesn't show:
+#ifdef __WXMAC__
+  event.Skip();
+#endif
 }
 
 
@@ -837,8 +938,11 @@ RapidSvnFrame::AddWcBookmark ()
   }
 
   // admin dir?
+  // TODO: Should we have a translated-once constant
+  // rather than keep converting SVN_WC_ADM_DIR_NAME?
   wxFileName fileName (dialog.GetPath ());
-  if ((fileName.GetName () + fileName.GetExt ()) == SVN_WC_ADM_DIR_NAME)
+  if ((fileName.GetName () + fileName.GetExt ()) ==
+      Utf8ToLocal (SVN_WC_ADM_DIR_NAME))
   {
     add = FALSE;
     wxMessageBox (_("You cannot add a subversion "
@@ -858,9 +962,9 @@ RapidSvnFrame::AddWcBookmark ()
 void
 RapidSvnFrame::AddRepoBookmark ()
 {
-  const int flags = 
-    UpdateDlg::WITH_URL | 
-    UpdateDlg::WITHOUT_RECURSIVE | 
+  const int flags =
+    UpdateDlg::WITH_URL |
+    UpdateDlg::WITHOUT_RECURSIVE |
     UpdateDlg::WITHOUT_REVISION;
   UpdateDlg dialog (this, _("Repository URL"), flags);
 
@@ -905,7 +1009,7 @@ RapidSvnFrame::InitFolderBrowser ()
   for (item = 0; item < count; item++)
   {
     key.Printf (ConfigBookmarkFmt, item);
-    if (pConfig->Read (key, &bookmark, ""))
+    if (pConfig->Read (key, &bookmark, wxEmptyString))
     {
       m_folder_browser->AddBookmark (bookmark);
     }
@@ -920,20 +1024,23 @@ RapidSvnFrame::InitFolderBrowser ()
 const svn::Targets
 RapidSvnFrame::GetActionTargets () const
 {
-  //is there nothing selected in the list control, 
+  //is there nothing selected in the list control,
   //or is the active window *not* the list control?
-  if (m_listCtrl->GetSelectedItemCount () <= 0 || 
+  if (m_listCtrl->GetSelectedItemCount () <= 0 ||
       m_activePane != ACTIVEPANE_FILELIST)
   {
     wxString path = m_folder_browser->GetPath ();
-    
-    if (!svn::Url::isValid (path))
+
+    std::string pathUtf8;
+    LocalToUtf8 (path, pathUtf8);
+    if (!svn::Url::isValid (pathUtf8.c_str ()))
     {
       wxFileName fname (path);
       path = fname.GetFullPath ();
+      LocalToUtf8 (path, pathUtf8);
     }
-    
-    return svn::Targets (path.c_str ());
+
+    return svn::Targets (pathUtf8.c_str ());
   }
   else
   {
@@ -946,27 +1053,28 @@ unsigned int
 RapidSvnFrame::GetSelectionActionFlags () const
 {
   unsigned int flags = 0;
-  
-  //is there nothing selected in the list control, 
+
+  //is there nothing selected in the list control,
   //or is the active window *not* the list control?
-  if (m_listCtrl->GetSelectedItemCount () <= 0 || 
+  if (m_listCtrl->GetSelectedItemCount () <= 0 ||
       m_activePane != ACTIVEPANE_FILELIST)
   {
     //yes, so examine the folder browser
-    
+
     flags |= Action::IS_DIR;
     wxString path = m_folder_browser->GetPath ();
-    const char * path_c = path.c_str ();
-    if (*path_c != '\0')
+    std::string pathUtf8;
+    LocalToUtf8 (path, pathUtf8);
+    if (!pathUtf8.empty ())
     {
       flags |= Action::SINGLE_TARGET;
-      if (svn::Url::isValid (path_c))
+      if (svn::Url::isValid (pathUtf8.c_str ()))
       {
         flags |= Action::RESPOSITORY_TYPE;
       }
       else
       {
-        if (svn::Wc::checkWc (path_c))
+        if (svn::Wc::checkWc (pathUtf8.c_str ()))
         {
           flags |= Action::VERSIONED_WC_TYPE;
         }
@@ -982,7 +1090,7 @@ RapidSvnFrame::GetSelectionActionFlags () const
     //no, ask the list control
     flags = m_listCtrl->GetSelectionActionFlags ();
   }
-  
+
   return flags;
 }
 
@@ -1004,87 +1112,87 @@ RapidSvnFrame::ValidateIDActionFlags (int id, unsigned int selectionActionFlags)
       // Special case of ExternalProgramAction - needs to be a working copy, not just single target
       baseActionFlags = ExternalProgramAction::GetBaseFlags () & ~Action::RESPOSITORY_TYPE;
       break;
-  
+
     case ID_Default_Action:
       baseActionFlags = ExternalProgramAction::GetBaseFlags ();
       break;
-  
+
     case ID_Update:
       baseActionFlags = UpdateAction::GetBaseFlags ();
       break;
-  
+
     case ID_Commit:
       baseActionFlags = CommitAction::GetBaseFlags ();
       break;
-  
+
     case ID_Add:
       baseActionFlags = AddAction::GetBaseFlags ();
       break;
-  
+
     case ID_AddRecursive:
       baseActionFlags = AddAction::GetBaseFlags ();
       break;
-  
+
     case ID_Import:
       baseActionFlags = ImportAction::GetBaseFlags ();
       break;
-  
+
     case ID_Checkout:
       baseActionFlags = CheckoutAction::GetBaseFlags ();
       break;
-  
+
     case ID_Cleanup:
       baseActionFlags = CleanupAction::GetBaseFlags ();
       break;
-  
+
     case ID_Log:
       baseActionFlags = LogAction::GetBaseFlags ();
       break;
-  
+
     case ID_Revert:
       baseActionFlags = RevertAction::GetBaseFlags ();
       break;
-  
+
     case ID_Resolve:
       baseActionFlags = ResolveAction::GetBaseFlags ();
       break;
-  
+
     case ID_Delete:
       baseActionFlags = DeleteAction::GetBaseFlags ();
       break;
-  
+
     case ID_Copy:
       baseActionFlags = MoveAction::GetBaseFlags ();
       break;
-  
+
     case ID_Move:
       baseActionFlags = MoveAction::GetBaseFlags ();
       break;
-  
+
     case ID_Mkdir:
       baseActionFlags = MkdirAction::GetBaseFlags ();
       break;
-  
+
     case ID_Merge:
       baseActionFlags = MergeAction::GetBaseFlags ();
       break;
-  
+
     case ID_Property:
       baseActionFlags = PropertyAction::GetBaseFlags ();
       break;
-  
-    case ID_Rename: 
+
+    case ID_Rename:
       baseActionFlags = MoveAction::GetBaseFlags ();
       break;
-  
+
     case ID_Switch:
       baseActionFlags = SwitchAction::GetBaseFlags ();
       break;
-  
+
     case ID_Diff:
       baseActionFlags = DiffAction::GetBaseFlags ();
       break;
-  
+
     case ID_Info:
       // Not actually part of the Action hierarchy, but here for completeness
       baseActionFlags = Action::SINGLE_TARGET|Action::MULTIPLE_TARGETS|Action::RESPOSITORY_TYPE|Action::VERSIONED_WC_TYPE|Action::UNVERSIONED_WC_TYPE;
@@ -1094,21 +1202,20 @@ RapidSvnFrame::ValidateIDActionFlags (int id, unsigned int selectionActionFlags)
       baseActionFlags = ViewAction::GetEditFlags ();
       break;
 
-    case ID_Contents: //TODO
     default:
       // If unrecognised, by default return true
       return true;
       break;
     }
   }
-  
+
   if (baseActionFlags & Action::WITHOUT_TARGET)
   {
     return true;
   }
-    
+
   // Check the sole quantity flag in selectedActionFlags is in baseActionFlags
-  // then check any type flags in selectedActionFlags are in baseActionFlags, but selectedActionFlags doesn't include any other types 
+  // then check any type flags in selectedActionFlags are in baseActionFlags, but selectedActionFlags doesn't include any other types
   return (selectionActionFlags & baseActionFlags & Action::TARGET_QUANTITY_MASK) != 0
             && (selectionActionFlags & baseActionFlags & Action::TARGET_TYPE_MASK) == (selectionActionFlags & Action::TARGET_TYPE_MASK);
 }
@@ -1133,7 +1240,7 @@ RapidSvnFrame::TrimDisabledMenuItems (wxMenu & menu)
       menu.Destroy (pItem);
     }
   }
-  
+
   // Trim unnecessary separators
   pos = menu.GetMenuItemCount ();
   bool sepNeeded = false;
@@ -1148,7 +1255,7 @@ RapidSvnFrame::TrimDisabledMenuItems (wxMenu & menu)
         ++pos;
         sepNeeded = false;
       }
-      
+
       if (sepNeeded)
       {
         sepNeeded = false;
@@ -1256,7 +1363,7 @@ RapidSvnFrame::OnFileCommand (wxCommandEvent & event)
       action = new PropertyAction (this);
       break;
 
-    case ID_Rename: 
+    case ID_Rename:
       action = new MoveAction (this, MOVE_RENAME);
       break;
 
@@ -1268,6 +1375,20 @@ RapidSvnFrame::OnFileCommand (wxCommandEvent & event)
       action = new DiffAction (this);
       break;
 
+    case ID_DiffBase:
+      {
+        DiffData data (svn::Revision::BASE);
+        action = new DiffAction (this, data);
+        break;
+      }
+
+    case ID_DiffHead:
+      {
+        DiffData data (svn::Revision::HEAD);
+        action = new DiffAction (this, data);
+        break;
+      }
+
     case ID_Edit:
       action = new ViewAction (this);
       break;
@@ -1285,9 +1406,8 @@ RapidSvnFrame::OnFileCommand (wxCommandEvent & event)
         wxOK);
       break;
 
-    case ID_Contents: //TODO
     default:
-      m_logTracer->Trace ("Unimplemented action!");
+      m_logTracer->Trace (_("Unimplemented action!"));
       break;
     }
   }
@@ -1341,10 +1461,18 @@ RapidSvnFrame::OnActionEvent (wxCommandEvent & event)
         // the next time the app gets activated
         m->updateAfterActivate = true;
       }
-      else if ((actionFlags & Action::DONT_UPDATE) == 0)
+      else
       {
-        Trace (_("Updating..."));
-        UpdateFileList ();
+        if ((actionFlags & Action::UPDATE_TREE) != 0)
+        {
+          Trace (_("Updating..."));
+          UpdateFolderBrowser ();
+        }
+        else if ((actionFlags & Action::DONT_UPDATE) == 0)
+        {
+          Trace (_("Updating..."));
+          UpdateFileList ();
+        }
       }
 
       Trace (_("Ready\n"));
@@ -1355,7 +1483,7 @@ RapidSvnFrame::OnActionEvent (wxCommandEvent & event)
   case TOKEN_VIEW:
     {
       GetData * pData = static_cast<GetData *>(event.GetClientData ());
-    
+
       if (pData != 0)
       {
         // copy the data first. This makes sure
@@ -1372,7 +1500,7 @@ RapidSvnFrame::OnActionEvent (wxCommandEvent & event)
 
   case TOKEN_ADD_BOOKMARK:
     {
-      const char * bookmark = event.GetString ().c_str ();
+      const wxString bookmark = event.GetString ();
 
       m_folder_browser->AddBookmark (bookmark);
       m_folder_browser->Refresh ();
@@ -1382,8 +1510,8 @@ RapidSvnFrame::OnActionEvent (wxCommandEvent & event)
 
   case TOKEN_GET:
     {
-      GetData * pData = static_cast<GetData *>(event.GetClientData ()); 
-    
+      GetData * pData = static_cast<GetData *>(event.GetClientData ());
+
       if (pData != 0)
       {
         // copy the data first. This makes sure
@@ -1397,7 +1525,7 @@ RapidSvnFrame::OnActionEvent (wxCommandEvent & event)
         Perform (action);
       }
     }
-    
+
     break;
   case TOKEN_DIFF:
     {
@@ -1467,7 +1595,7 @@ RapidSvnFrame::ShowInfo ()
   }
   catch (svn::ClientException & e)
   {
-    Trace (e.message ());
+    Trace (Utf8ToLocal (e.message ()));
     return;
   }
 
@@ -1514,7 +1642,7 @@ RapidSvnFrame::UpdateCurrentPath ()
 {
   if (m_folder_browser == 0)
   {
-    m_currentPath = "";
+    m_currentPath.Clear ();
     m_context = 0;
   }
   else
@@ -1523,7 +1651,7 @@ RapidSvnFrame::UpdateCurrentPath ()
     m_context = m_folder_browser->GetContext ();
   }
 
-  SetTitle (m_title + ": " + m_currentPath);
+  SetTitle (m_title + wxT(": ") + m_currentPath);
 }
 
 bool
@@ -1534,7 +1662,7 @@ RapidSvnFrame::InvokeDefaultAction ()
 
   // the default action will be invoked only for a single file
   // or folder.
-  // if more or less than one file or folder is selected nothing 
+  // if more or less than one file or folder is selected nothing
   // will happen.
 
   if (targets.size () != 1)
@@ -1543,7 +1671,7 @@ RapidSvnFrame::InvokeDefaultAction ()
   if (selectionActionFlags & Action::IS_DIR)
   {
     // go one folder deeper...
-    m_folder_browser->SelectFolder (targets[0].c_str ());
+    m_folder_browser->SelectFolder (Utf8ToLocal(targets[0].c_str ()));
   }
   else
   {
@@ -1561,7 +1689,9 @@ RapidSvnFrame::Perform (Action * action)
     m->SetRunning (true);
     m->listener.cancel (false);
 
-    action->SetPath (m_currentPath.c_str ());
+    std::string currentPathUtf8;
+    LocalToUtf8(m_currentPath, currentPathUtf8);
+    action->SetPath (svn::Path (currentPathUtf8));
     action->SetContext (m_context);
     if ((action->GetFlags () & Action::WITHOUT_TARGET) == 0)
     {
@@ -1580,13 +1710,13 @@ RapidSvnFrame::Perform (Action * action)
   }
 }
 
-void 
+void
 RapidSvnFrame::OnFileListSelected (wxListEvent & event)
 {
   m_activePane = ACTIVEPANE_FILELIST;
 }
 
-void 
+void
 RapidSvnFrame::OnColumn (wxCommandEvent & event)
 {
   bool visible = m->IsColumnChecked(event.m_id);
@@ -1620,6 +1750,15 @@ RapidSvnFrame::OnRefreshWithUpdate (wxCommandEvent & WXUNUSED (event))
 }
 
 
+void
+RapidSvnFrame::OnShowUnversioned (wxCommandEvent & WXUNUSED (event))
+{
+  bool checked = m->IsMenuChecked (ID_ShowUnversioned);
+  m_listCtrl->SetShowUnversioned (checked);
+  UpdateFolderBrowser ();
+}
+
+
 void
 RapidSvnFrame::OnColumnReset (wxCommandEvent &)
 {
@@ -1636,12 +1775,12 @@ RapidSvnFrame::OnColumnReset (wxCommandEvent &)
   UpdateFileList ();
 }
 
-void 
+void
 RapidSvnFrame::UpdateFolderBrowser ()
 {
   wxBusyCursor busy;
 
-  m_currentPath = "";
+  m_currentPath.Clear ();
   UpdateFileList ();
 
   m->SetRunning (true);
@@ -1664,17 +1803,16 @@ RapidSvnFrame::UpdateFolderBrowser ()
 }
 
 void
-RapidSvnFrame::Trace (const char *msg)
+RapidSvnFrame::Trace (wxString msg)
 {
-  if (m_log != 0)
+  if (m_log != NULL)
   {
-    wxString message;
-    message.Printf ("%s\n", msg);
-    m_log->AppendText (message);
+    msg += wxT('\n');
+    m_log->AppendText (msg);
   }
 }
 
-void 
+void
 RapidSvnFrame::OnLogin (wxCommandEvent & event)
 {
   svn::Context * context = m_folder_browser->GetContext ();
@@ -1682,16 +1820,20 @@ RapidSvnFrame::OnLogin (wxCommandEvent & event)
   if (context == 0)
     return;
 
-  AuthDlg dlg (this, context->getUsername ());
+  wxString LocalUsername(Utf8ToLocal (context->getUsername ()));
+  AuthDlg dlg (this, LocalUsername);
   bool ok = dlg.ShowModal () == wxID_OK;
 
   if (ok)
   {
-    context->setLogin (dlg.GetUsername (), dlg.GetPassword ());
+    std::string username, password;
+    LocalToUtf8 (dlg.GetUsername (), username);
+    LocalToUtf8 (dlg.GetPassword (), password);
+    context->setLogin (username.c_str (), password.c_str ());
   }
 }
 
-void 
+void
 RapidSvnFrame::OnLogout (wxCommandEvent & event)
 {
   svn::Context * context = m_folder_browser->GetContext ();
@@ -1702,30 +1844,13 @@ RapidSvnFrame::OnLogout (wxCommandEvent & event)
   context->setLogin ("", "");
 }
 
-void 
+void
 RapidSvnFrame::OnStop (wxCommandEvent & event)
 {
   m->listener.cancel (true);
 }
 
-InfoPanel::InfoPanel (wxWindow * parent)
-  : wxPanel (parent, -1, wxDefaultPosition, wxDefaultSize, 
-             wxTAB_TRAVERSAL | wxCLIP_CHILDREN)
-{
-}
 
-LogTracer::LogTracer (wxWindow * parent)
-  : wxTextCtrl (parent, -1, "", wxPoint (0, 0),
-                wxDefaultSize, wxTE_MULTILINE | wxTE_READONLY)
-{
-  SetMaxLength (0);
-}
-
-void
-LogTracer::Trace (const wxString & str)
-{
-  AppendText (str + "\n");
-}
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
