@@ -13,7 +13,7 @@
 // stl
 #include <vector>
 
-// wxwindows
+// wxWidgets
 #include "wx/wx.h"
 #include "wx/datetime.h"
 
@@ -48,8 +48,8 @@
 /** configuration options */
 
 /**
- * Some wxWindows released have know bugs with menu entries
- * with bitmaps. wxWindows 2.4.1 doesnt fire events when
+ * Some wxWidgets released have know bugs with menu entries
+ * with bitmaps. wxWidgets 2.4.1 doesnt fire events when
  * using menu items with bitmaps attached.
  * Set this option to "false" if you encounter this.
  * Default: true
@@ -58,8 +58,8 @@ static const bool UseBitmapMenus = false;
 
 static wxMenuItem *
 CreateMenuItem (
-  wxMenu * parentMenu, int id, const wxString & text, 
-  const wxBitmap & bitmap) 
+  wxMenu * parentMenu, int id, const wxString & text,
+  const wxBitmap & bitmap)
 {
   wxMenuItem * item = new wxMenuItem (parentMenu, id, text);
   if(UseBitmapMenus)
@@ -67,17 +67,17 @@ CreateMenuItem (
   return item;
 }
 
-static wxMenuItem * 
+static wxMenuItem *
 CreateMenuItem (
-  wxMenu * parentMenu, int id, const wxString & text) 
+  wxMenu * parentMenu, int id, const wxString & text)
 {
   return new wxMenuItem (parentMenu, id, text);
 }
 
 static wxMenuItem *
 AppendMenuItem (
-  wxMenu * parentMenu, int id, const wxString & text, 
-  const wxBitmap & bitmap) 
+  wxMenu * parentMenu, int id, const wxString & text,
+  const wxBitmap & bitmap)
 {
   wxMenuItem * item = CreateMenuItem (parentMenu, id, text, bitmap);
   parentMenu->Append (item);
@@ -86,7 +86,7 @@ AppendMenuItem (
 
 static wxMenuItem *
 AppendMenuItem (
-  wxMenu * parentMenu, int id, const wxString & text) 
+  wxMenu * parentMenu, int id, const wxString & text)
 {
   wxMenuItem * item = CreateMenuItem (parentMenu, id, text);
   parentMenu->Append (item);
@@ -96,7 +96,7 @@ AppendMenuItem (
 wxString & UnixPath (wxString & path)
 {
 #ifdef _WIN32
-  path.Replace("\\", "/");
+  path.Replace(wxT("\\"), wxT("/"));
 #endif
   return path;
 }
@@ -113,16 +113,16 @@ bool PostMenuEvent (wxEvtHandler *source, long id)
 {
   // This is the way it's done in wxFrame
   wxCommandEvent event (wxEVT_COMMAND_MENU_SELECTED, id);
-  
+
   event.SetEventObject (source);
-  
+
   return source->ProcessEvent (event);
 }
 
 wxButton *
 CreateEllipsisButton(wxWindow *parent, long id)
 {
-  const char *ELLIPSIS = "...";
+  const wxChar *ELLIPSIS = wxT("...");
   int ellipsis_width, ellipsis_height;
 
   wxButton *button = new wxButton (parent, id, ELLIPSIS);
@@ -134,7 +134,7 @@ CreateEllipsisButton(wxWindow *parent, long id)
   return button;
 }
 
-void 
+void
 AppendModifyMenu (wxMenu * parentMenu)
 {
   AppendMenuItem (*parentMenu, ID_Edit);
@@ -164,19 +164,22 @@ AppendModifyMenu (wxMenu * parentMenu)
                   wxBitmap (resolve_xpm));
 
   parentMenu->AppendSeparator ();
-  
+
   AppendMenuItem (parentMenu, ID_Copy, _("&Copy...\tF5"));
   AppendMenuItem (parentMenu, ID_Move, _("M&ove...\tF6"));
   AppendMenuItem (parentMenu, ID_Rename, _("Re&name...\tCTRL-N"));
   AppendMenuItem (parentMenu, ID_Mkdir, _("Make &directory...\tF7"));
 }
 
-void 
+void
 AppendQueryMenu (wxMenu * parentMenu)
 {
+  AppendMenuItem (parentMenu, ID_Diff, _("&Diff...\tCTRL+D"));
+  AppendMenuItem (parentMenu, ID_DiffBase, _("&Diff to Base...\tCTRL+B"));
+  AppendMenuItem (parentMenu, ID_DiffHead, _("&Diff to Head...\tCTRL+H"));
+  parentMenu->AppendSeparator ();
   AppendMenuItem (parentMenu, ID_Log, _("&Log...\tCTRL-L"),
                   wxBitmap (log_xpm));
-  AppendMenuItem (parentMenu, ID_Diff, _("&Diff...\tCTRL+D"));
   AppendMenuItem (parentMenu, ID_Info, _("&Info...\tCTRL-I"),
                   wxBitmap (info_xpm));
 }
@@ -190,7 +193,7 @@ AppendBookmarksMenu (wxMenu * parentMenu)
 }
 
 bool
-CheckRevision (const char * revstring)
+CheckRevision (const wxString & revstring)
 {
   svn_revnum_t revnum;
 
@@ -202,14 +205,14 @@ CreateActionEvent (int token)
 {
   wxCommandEvent event (wxEVT_COMMAND_MENU_SELECTED, ACTION_EVENT);
   event.SetInt (token);
-  
+
   return event;
 }
 
 wxMenuItem *
 AppendMenuItem (wxMenu & menu, int id)
 {
-  const char * caption = "";
+  wxString caption;
   wxBitmap bitmap;
 
   switch (id)
@@ -226,7 +229,7 @@ AppendMenuItem (wxMenu & menu, int id)
   case ID_AddRepoBookmark:
     caption = _("Add Existing &Repository...");
     break;
-  
+
   case ID_RemoveBookmark:
     caption = _("&Remove Bookmark...");
     bitmap = wxBitmap (remove_bookmark_xpm);
@@ -314,7 +317,7 @@ ParseDateTime (const wxString & datestring, apr_time_t & date)
   // (we check only if the complete parsing failed,
   //  not if only the partial string could be parsed)
   wxDateTime dateTime;
-  if (dateTime.ParseFormat (datestring, "%c") ==0)
+  if (dateTime.ParseFormat (datestring, wxT("%c")) ==0)
     return false;
 
   apr_time_ansi_put (&date, dateTime.GetTicks ());
@@ -334,30 +337,32 @@ CheckDateTime (const wxString & datestring)
 wxString
 FormatDateTime (apr_time_t date, wxString fmt)
 {
+  wxString wxstrtime;
+
   if (date == 0)
-    return "";
+    return wxstrtime;
 
   apr_time_exp_t exp_time;
   char timestr[80];
 
   apr_time_exp_lt (&exp_time, date);
   apr_size_t size;
-  apr_status_t apr_err = 
+  apr_status_t apr_err =
     apr_strftime (timestr, &size, sizeof (timestr),
                   "%x %X", &exp_time);
 
-  /* if that failed, just zero out the string and print nothing */
-  if (apr_err)
-    timestr[0] = '\0';
+  /* if that failed, just leave the string empty */
+  if (!apr_err)
+    wxstrtime = wxString::FromAscii(timestr)  ;
 
-  return timestr;
+  return wxstrtime;
 }
 
 
-wxString 
+wxString
 BeautifyPath (const wxString & path)
 {
-  int pos = path.Find (":");
+  int pos = path.Find (wxT(":"));
 
   if (pos <= 0)
     return path;
@@ -410,23 +415,78 @@ StatusDescription (const svn_wc_status_kind kind)
   }
 }
 
-
-wxString
-Utf8ToLocal (const wxString & srcUtf8)
+#if !wxUSE_UNICODE
+static wxMBConv *
+GetWXLocalConv ()
 {
-  wxString dst (srcUtf8, wxConvUTF8);
+#if defined(__WXGTK20__)
+  // In wxGTK 2.0+, for some reason wvConvCurrent
+  // is always set to wxConvUTF8 - which is not correct!
+  // We will instead echo some logic in wxEntryStart
+  // to choose between wxConvLibc & wxConvLocal.
+  static wxMBConv *wxConvCorrect = NULL;
 
-  return srcUtf8;
+  if (wxConvCorrect == NULL)
+  {
+    if (wxOKlibc ())
+    {
+      wxConvCorrect = &wxConvLibc;
+    }
+    else
+    {
+      wxConvCorrect = &wxConvLocal;
+    }
+  }
+
+  return wxConvCorrect;
+#else
+  // Use what wxWidgets has already selected to be the correct conversion
+  return wxConvCurrent;
+#endif
 }
+#endif
 
 wxString
-LocalToUtf8 (const wxString & srcLocal)
+Utf8ToLocal (const char* srcUtf8)
 {
-  wxString dst (srcLocal.mb_str (wxConvUTF8));
+#if wxUSE_UNICODE
+  wxString dst (srcUtf8, wxConvUTF8);
+#else
+  wxString dst (wxConvUTF8.cMB2WC(srcUtf8), *GetWXLocalConv ());
+#endif
 
   return dst;
 }
 
+wxString
+Utf8ToLocal (const std::string& srcUtf8)
+{
+  return Utf8ToLocal(srcUtf8.c_str());
+}
+
+std::string
+LocalToUtf8 (const wxString & srcLocal)
+{
+#if wxUSE_UNICODE
+  std::string dst (srcLocal.mb_str (wxConvUTF8));
+#else
+  wxString wxdst (srcLocal.wc_str (*GetWXLocalConv ()), wxConvUTF8);
+  std::string dst (wxdst.mb_str ());
+#endif
+
+  return dst;
+}
+
+void
+LocalToUtf8 (const wxString & srcLocal, std::string & dstUtf8)
+{
+#if wxUSE_UNICODE
+  dstUtf8 = srcLocal.mb_str (wxConvUTF8);
+#else
+  wxString wxdst (srcLocal.wc_str (*GetWXLocalConv ()), wxConvUTF8);
+  dstUtf8 = wxdst.mb_str ();
+#endif
+}
 
 void
 AppendVerbMenu (wxMenu * parentMenu, svn::Status * status)
@@ -438,7 +498,10 @@ AppendVerbMenu (wxMenu * parentMenu, svn::Status * status)
     {
       VerbList verbList;
 
-      verbList.InitFromDocument (status->path ());
+      // We don't want verbs on directories, even though they exist
+      bool isADirectory = status->entry ().kind () == svn_node_dir;
+      if (!isADirectory)
+        verbList.InitFromDocument (Utf8ToLocal (status->path ()), isADirectory );
 
       if (verbList.GetCount () == 0)
         return;
@@ -446,23 +509,25 @@ AppendVerbMenu (wxMenu * parentMenu, svn::Status * status)
       wxMenu * menu = new wxMenu ();
 
       size_t i = 0;
-      for (; 
-           (i < verbList.GetCount ()) && 
+      for (;
+           (i < verbList.GetCount ()) &&
            (i < (ID_Verb_Max - ID_Verb_Min + 1)); i++)
       {
         wxMenuItem *pItem;
         // TODO: Convert verb names to unicode on the fly if needed (or make
-        // verblist follow wxWindows' unicode setting)
-        pItem = new wxMenuItem (menu, ID_Verb_Min + i, verbList.GetName (i));
+        // verblist follow wxWidgets' unicode setting)
+        // TODO: Note: I think verbList.GetName is a Windows code-paged char *, not UTF 8, so don't use Utf8ToLocal like elsewhere
+        // Someone will need to put the correct mappings in eventually
+        pItem = new wxMenuItem (menu, ID_Verb_Min + i, wxString::FromAscii (verbList.GetName (i)));
         //pItem->SetBitmap (wxBITMAP (?))
         menu->Append (pItem);
       }
-    
+
       parentMenu->Append (ID_Open, _("Open..."), menu);
     }
     catch (std::exception)
     {
-      // Failed assembling verbs. 
+      // Failed assembling verbs.
       // TODO: Report this error in the status bar?
 
     }
